# -*- coding: utf-8 -*-

# Copyright 2011-2024, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


"""This module handles the path to the main configuration file in the "old school" way, up to interiorcad 2024 F4.x

This module is new for interiprcad 2024 F5"""

from functools import lru_cache

try:
    import _interiorcadexportsettingsfile

    if hasattr(_interiorcadexportsettingsfile, 'getMainConfigurationFilePath'):
        # From interiorcad 2023 F6.0 on to interiorcad 2024 F5
        @lru_cache()
        def getMainConfigurationFilePathOldSchool() -> str:
            return _interiorcadexportsettingsfile.getMainConfigurationFilePath()

    else:
        # Before interiorcad 2023 F6.0
        @lru_cache()
        def getMainConfigurationFilePathOldSchool() -> str:
            esf = _interiorcadexportsettingsfile.ExportSettingsFile()
            return esf.getPathInUserFolder()

except ImportError:

    def getMainConfigurationFilePathOldSchool() -> str:
        return ""
