# -*- coding: utf-8 -*-

# Copyright 2015-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import functools

from interiorcad.backend.cmoduleadapters.utilities import convertVerticesFromPositionTuplesToDict, getStupidBoundsOfVertices

try:
    import _jointsizingpath

    if hasattr(_jointsizingpath, 'getPathClockWiseAndBounds'):  # New in interiorcad 2019 F7
        # This function does not need to be cached, as the new code calls it only once per UUID.
        def getJointPathClockWiseAndBounds(*args):
            return _jointsizingpath.getPathClockWiseAndBounds(*args)

        @functools.lru_cache(maxsize=None)
        def getJointSizingPath(*args):
            # The vertices in the path have too many data, but we do not care as vertex[0] and vertex[1] are still OK
            return _jointsizingpath.getPathClockWiseAndBounds(*args)[0]

    elif hasattr(_jointsizingpath, 'getPathClockWise'):
        def getJointPathClockWiseAndBounds(*args):
            path = getJointSizingPath(*args)
            return convertVerticesFromPositionTuplesToDict(path), getStupidBoundsOfVertices(path)

        @functools.lru_cache(maxsize=None)
        def getJointSizingPath(*args):
            return _jointsizingpath.getPathClockWise(*args)

    else:
        import logging
        from interiorcad.backend.datatracker.exportdatacollector import ExportDataCollector

        def getJointPathClockWiseAndBounds(*args):
            path = getJointSizingPath(*args)
            return convertVerticesFromPositionTuplesToDict(path), getStupidBoundsOfVertices(path)

        @functools.lru_cache(maxsize=None)
        def getJointSizingPath(uuid, *args):
            name = ExportDataCollector.getUniqueName(uuid)
            # The warning message cannot be translated, as it will show only on older versions of interiorcad, which would lack the translation
            logging.warning("Please check the direction of the non-rectangular sizing (incl. radius compensation) and of miters. (Or use interiorcad from 2016 F3 on). Workpiece: " + name)
            return _jointsizingpath.getPath(uuid, *args)


except ImportError:
    def getJointPathClockWiseAndBounds(*args):
        raise RuntimeError("interiorcad is not running (or the version of interiorcad is before 2015 F3).")

    def getJointSizingPath(*_args):
        raise RuntimeError("interiorcad is not running (or the version of interiorcad is before 2015 F3).")
