# -*- coding: utf-8 -*-

# Copyright 2011-2022, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import functools
import re

try:
    import _interiorcadboards
    boards = _interiorcadboards

except ImportError:

    import interiorcad.backend.cmoduleadapters.materials.mockBoards as mockBoards
    boards = mockBoards.mockBoardsInstance

    def setTestDatabase(dbFilename):
        global clearCaches
        mockBoards.setTestDatabase(dbFilename)
        clearCaches()

    def closeDatabaseConnection():
        mockBoards.closeDatabaseConnection()


CACHE_LENGTH = None


def clearCaches():
    for item in globals().values():
        if hasattr(item, 'cache_clear') and callable(item.cache_clear):
            item.cache_clear()


if hasattr(boards, 'getBoardsData'):  # New in interiorcad 2022 F1
    @functools.lru_cache(maxsize=CACHE_LENGTH)
    def getBoardsData(materialID):
        return boards.getBoardsData(materialID)
else:
    def getBoardsData(materialID):  # Up to interiorcad 2022 F1
        return tuple()
        # return tuple(uuid for uuid in datatracker.getUUIDListForExport())

if hasattr(boards, 'getBoardType'):  # New in interiorcad 2022 F4
    @functools.lru_cache(maxsize=CACHE_LENGTH)
    def getBoardType(materialID):
        return boards.getBoardType(materialID)
else:
    @functools.lru_cache(maxsize=CACHE_LENGTH)
    def getBoardType(materialID):
        # Try to simulate the different types of German materials (not all will work correctly, as defined in Boards.txt)
        if re.search('^Fpy-[A-Za-z]+-[0-9]+$', materialID) or re.search('^KF-[A-Za-z]+-[0-9]+$', materialID) :
            return 'veneer'
        elif re.search('^Fpy-Deco-[0-9]+$', materialID) or re.search('^KF-[FH].+$', materialID):
            return 'melamine'
        elif re.search('^L[Hh]-[A-Za-z]+-[0-9]+$', materialID):
            return 'gw'
        elif re.search('^MH-3S-[A-Za-z]+-[0-9]+$', materialID):
            return '3l'
        elif re.search('^MH-[0-9]+$', materialID) or re.search('^MH-[A-Za-z]+-[0-9]+$', materialID):
            return 'solid'

        return 'custom'
