# -*- coding: utf-8 -*-

# Copyright 2011-2021, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import functools
import json

try:
    import _interiorcadfinishings
    finishings = _interiorcadfinishings

except ImportError:
    import interiorcad.backend.cmoduleadapters.materials.mockFinishings as mockFinishings
    finishings = mockFinishings.mockFinishingsInstance

    def setTestDatabase(dbFilename):
        global clearCaches
        mockFinishings.setTestDatabase(dbFilename)
        clearCaches()

    def closeDatabaseConnection():
        mockFinishings.closeDatabaseConnection()


CACHE_LENGTH = None


def clearCaches():
    for item in globals().values():
        if hasattr(item, 'cache_clear') and callable(item.cache_clear):
            item.cache_clear()


if hasattr(finishings, 'getFinishingsData'):  # New in interiorcad 2022 F1

    @functools.lru_cache(maxsize=CACHE_LENGTH)
    def getFinishingsData(materialID):
        return finishings.getFinishingsData(materialID)

else:

    @functools.lru_cache(maxsize=CACHE_LENGTH)
    def getFinishingsData(materialID):  # Up to interiorcad 2022 F1
        return tuple()
        # return tuple(uuid for uuid in datatracker.getUUIDListForExport())
