# -*- coding: utf-8 -*-

# Copyright 2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

"""Module for utilities for cmodule adapters, especially for older interiorcad versions"""

import collections

# TODO IT-240: UnitTests would be nice to avoid breaking code. -- NG


def convertVerticesFromNamedTupleToDict(vertices):
    return (
        {
            'x': vertex.x,
            'y': vertex.y,
            'type': vertex.type,
            'radius': vertex.radius,
            'visible': vertex.visible,
        }
        for vertex in vertices
    )


def convertVisibleCornerVerticesFromPositionsToDict(positions):
    return (
        {
            'x': position.x,
            'y': position.y,
            'type': 0,
            'radius': 0,
            'visible': True,
        }
        for position in positions
    )


def convertVerticesFromPositionsToDict(vertices):
    return (
        {
            'x': vertex.position.x,
            'y': vertex.position.y,
            'type': vertex.type,
            'radius': vertex.radius,
            'visible': vertex.visible,
        }
        for vertex in vertices
    )


def convertVerticesFromPositionTuplesToDict(positions):
    return (
        {
            'x': position[0],
            'y': position[1],
            'type': 0,
            'radius': 0,
            'visible': True,
        }
        for position in positions
    )


def getStupidBoundsOfVertices(positions):
    """Get bounds of polygonal vertices.

        This WILL NOT work correctly for polylines
    """
    maxXVertex = max(positions, key=lambda position: position[0])
    maxYVertex = max(positions, key=lambda position: position[1])
    minXVertex = min(positions, key=lambda position: position[0])
    minYVertex = min(positions, key=lambda position: position[1])

    return minXVertex[0], minYVertex[1], maxXVertex[0], maxYVertex[1]


def createIdentityMatrixAsNamedTuple():
    Matrix = collections.namedtuple("MatrixRaw", "a00 a01 a02 a10 a11 a12 a20 a21 a22 xOffset yOffset zOffset")
    return Matrix(
        1.0, 0.0, 0.0,
        0.0, 1.0, 0.0,
        0.0, 0.0, 1.0,
        0.0, 0.0, 0.0
    )
