# -*- coding: utf-8 -*-

# Copyright 2011-2024, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

import interiorcad.interface.configurationkeys as ConfigurationKeys
from interiorcad.backend.exportmainpath import getMainConfigurationFilePath

from interiorcad.backend.mockexportsettingsfile import INTERIORCAD_MACHINE_EXPORT_SETTINGS_XML
from interiorcad.backend.xmlparser import XMLParser


def setXmlRoot(this: XMLParser) -> None:
    path = getMainConfigurationFilePath()
    if path:
        this.parseFromFile(path)
    else:
        this.parseFromString(INTERIORCAD_MACHINE_EXPORT_SETTINGS_XML)


class ExportSettingsFile(XMLParser):
    def __init__(self):
        super().__init__()
        setXmlRoot(self)


class Tests(unittest.TestCase):
    def setUp(self):
        self.xmlParser = ExportSettingsFile()

    def testGetSeparateSizingValueShouldWork(self):
        self.assertEqual('0', self.xmlParser.getSimpleValue(ConfigurationKeys.NC_OUTPUT_SEPARATE_SIZING))

    def testGetCommonJointingEnabledShouldReturnFalse(self):
        self.assertEqual('0', self.xmlParser.getSimpleValue(ConfigurationKeys.COMMON_JOINTING))

    def testGetCommonJointingMinMaxShouldReturnCorrectValues(self):
        self.assertEqual('2.000000', self.xmlParser.getSimpleValue(ConfigurationKeys.COMMON_JOINTING_MIN))
        self.assertEqual('5.000000', self.xmlParser.getSimpleValue(ConfigurationKeys.COMMON_JOINTING_MAX))
