# -*- coding: utf-8 -*-

# Copyright 2011-2017, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

from interiorcad.interface.geometry.rectangle import Rectangle
from interiorcad.interface.geometry import isNearlyEqual


class JointCalculator:
    def __init__(self, minJoint, maxJoint):
        self.minJoint = minJoint
        self.maxJoint = maxJoint

    def getJointAddition(self, addition):
        jointLeft = self.getValidJoint(addition.left)
        jointRight = self.getValidJoint(addition.right)
        jointTop = self.getValidJoint(addition.top)
        jointBottom = self.getValidJoint(addition.bottom)
        return Rectangle(left=jointLeft, bottom=jointBottom, right=jointRight, top=jointTop)

    def getValidJoint(self, edgeThickness):
        validJoint = edgeThickness
        if edgeThickness < self.minJoint and not isNearlyEqual(edgeThickness, 0):
            validJoint = self.minJoint
        if edgeThickness > self.maxJoint:
            validJoint = self.maxJoint
        return validJoint

    def isJointInBounds(self, joint):
        return isNearlyEqual(joint, self.getValidJoint(joint))


class JointCalculatorTests(unittest.TestCase):
    def setUp(self):
        minJoint = 2.0
        maxJoint = 5.0
        self.calculator = JointCalculator(minJoint, maxJoint)

    def testGetValidJoint(self):
        self.assertAlmostEqual(2.0, self.calculator.getValidJoint(1.5))
        self.assertAlmostEqual(3.0, self.calculator.getValidJoint(3.0))
        self.assertAlmostEqual(5.0, self.calculator.getValidJoint(6.0))

    def testIsJointOufOfBounds(self):
        self.assertTrue(self.calculator.isJointInBounds(3))
        self.assertFalse(self.calculator.isJointInBounds(1))
        self.assertFalse(self.calculator.isJointInBounds(10))

    def testNoEdge(self):
        self.assertAlmostEqual(0, self.calculator.getValidJoint(0))
        self.assertTrue(self.calculator.isJointInBounds(0))
