# -*- coding: utf-8 -*-

# Copyright 2011-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import functools

try:
    import _interiorcadlocalization

except ImportError:
    class _interiorcadlocalization:
        @staticmethod
        def getLocalizedString(_resourceGroup, _resourceID, defaultText):
            return defaultText


CUTTINGLIST_RESOURCEGROUP = 11012
NCEXPORT_NCPROGRAMS_RESOURCEGROUP = 11013
NCEXPORT_MESSAGES_RESOURCEGROUP = 11014
CUTTINGLIST_OUTPUT_FILE_NAMES_RESOURCEGROUP = 11017
WOODWOPPROGRAMVARIABLES_RESOURCEGROUP = 11018
NCHOPSPROGRAMVARIABLES_RESOURCEGROUP = 11020
IMAWOPPROGRAMVARIABLES_RESOURCEGROUP = 11021
XILOGPROGRAMCOMMENTS_RESOURCEGROUP = 11023
WINXISO_MESSAGES_RESOURCEGROUP = 11024
FILE_NAME_POSTFIXES_RESOURCEGROUP = 11025
SIDE_NAMES_RESOURCEGROUP = 11026
WOODWOP_KM_COMMENTS_RESOURCEGROUP = 11110
WOODWOP_MACRO_COMMENTS_RESOURCEGROUP = 11111
WOODWOP_KAT_CATEGORIES_RESOURCEGROUP = 11112
WOODWOP_MNM_CATEGORIES_RESOURCEGROUP = 11113
IMAWOP_DESCRIPTIONS_RESOURCEGROUP = 11114
WOODFLASH_SIDE_DESCRIPTIONS_RESOURCEGROUP = 11115
GANNOMAT_MESSAGES_RESOURCEGROUP = 11116
CUTTINGLISTEXPORT_MESSAGES = 11117
MAESTRO_NAME_MESSAGES = 11118
XCONVERTER_MESSAGES_RESOURCEGROUP = 11119
BIESSE_CIX_NAME_MESSAGES = 11120
MAESTRO_PROGRAM_COMMENTS_RESOURCEGROUP = 11121
MAESTRO_MULTI_CENTER_STUDIO_PROGRAM_COMMENTS_RESOURCEGROUP = 11122
BIESSE_CIX_MESSAGES = 11123
XILOG_MESSAGES = 11124
WOODWOP_MESSAGES = 11125
NCEXPORTBASE_MESSAGES = 11126
WOODFLASH_COMMENT_MESSAGES = 11127
IMAWOP_NAME_MESSAGES = 11128
F4INTEGRATE_COMMENT_MESSAGES = 11129
MASTERWORK_DESCRIPTIONS_RESOURCEGROUP = 11130
LICENSE_ERRORS_RESOURCEGROUP = 11131
COMMON_MESSAGES_RESOURCEGROUP = 11132


@functools.lru_cache(maxsize=1024)
def getLocalizedString(groupId, messageId, message):
    assert isinstance(message, str), "message is not a string!"
    if groupId is not None and messageId is not None:
        return _interiorcadlocalization.getLocalizedString(groupId, messageId, message)
    else:
        return message


# CAREFUL: the IDs are ConstructionGroupID (dev\SharedWithClassic\ConstructionGroupID.h), not the indices of string group 11022 of XGCabinet!
CONSTRUCTION_GROUP_NAMES = {
    -1: 'Undefined',
    0: 'Cabinet Shelf / Stretcher',
    1: 'Side / Stile',
    2: 'Plinth',
    3: 'Scribe',
    4: 'Back',
    5: 'Fixed Shelf',
    6: 'Door',
    7: 'Drawer Front',
    8: 'Cabinet Handles',
    9: 'Cabinet Legs',
    10: 'Partition / Stile',
    11: 'Movable Shelf',
    12: 'Generic Custom Part',
    13: 'Blind Front',
    14: 'Nailer',
    15: 'Frame Stile',
    16: 'Frame Rail',
    17: 'Frame Inner Stile',
    18: 'Frame Inner Rail',
    19: 'Frame Panel',
    20: 'Flap',
    21: 'Faceframe Stile',
    22: 'Faceframe Rail',
    23: 'Faceframe Inner Stile',
    24: 'Faceframe Inner Rail',
    25: 'Faceframe',
    26: 'Wooden Drawer Base',
    27: 'Wooden Drawer Front',
    28: 'Wooden Drawer Back',
    29: 'Wooden Drawer Side',
    30: 'System Drawer Base',
    31: 'System Drawer Back',
    32: 'Wooden Drawer',
}


# New in interiorcad 2020 F3
# Original string resources for getConstructionGroupName: XG Cabinet/.../11022 Construction Groups.vwstrings
# The order of the CONSTRUCTION_GROUP_NAMES is different from 11022 Construction Groups.vwstrings!
@functools.lru_cache(None)
def getConstructionGroupName(cgid, cgcid):
    if cgid == -1:   # Generic Custom Parts und Drawer Parts
        return getConstructionGroupComponentName(cgcid)
    elif hasattr(_interiorcadlocalization, 'getConstructionGroupName'):
        return _interiorcadlocalization.getConstructionGroupName(cgid)
    elif cgid in CONSTRUCTION_GROUP_NAMES:
        return CONSTRUCTION_GROUP_NAMES[cgid]
    else:
        return f'CG Name {cgid}'  # We cannot translate, as an older interiorcad would not have the translation


# CAREFUL: the IDs are ConstructionGroupComponentID (dev\SharedWithClassic\CGCMap\ConstructionGroupComponentID.h), not the indices of string group 11106 of XGCabinet!
CONSTRUCTION_GROUP_COMPONENT_NAMES = {
    0: 'Generic Custom Part',
    1: 'Back',
    2: 'Side Left',
    3: 'Side Right',
    4: 'Stile Left Front',
    5: 'Stile Left Back',
    6: 'Stile Right Front',
    7: 'Stile Right Back',
    8: 'Partition',
    9: 'Partition Stile Front',
    10: 'Partition Stile Back',
    11: 'Shelf Top',
    12: 'Shelf Bottom',
    13: 'Stretcher Top Front',
    14: 'Stretcher Top Back',
    15: 'Stretcher Bottom Front',
    16: 'Stretcher Bottom Back',
    17: 'Fixed Shelf',
    18: 'Stretcher Front',
    19: 'Stretcher Back',
    20: 'Movable Shelf',
    21: 'Door',
    22: 'Drawer Front',
    23: 'Plinth Front',
    24: 'Plinth Left',
    25: 'Plinth Right',
    26: 'Plinth Back',
    27: 'Plinth Stretcher',
    28: 'Scribe Top',
    29: 'Scribe Right',
    30: 'Scribe Left',
    31: 'Drawer Base',
    32: 'Drawer Back',
    33: 'Drawer Base',
    34: 'Drawer Back',
    35: 'Drawer Front Piece',
    36: 'Drawer Left',
    37: 'Drawer Right',
    38: 'Plinth Front',
    39: 'Plinth Left',
    40: 'Plinth Right',
    41: 'Plinth Back',
    42: 'Plinth Stretcher',
    43: 'Blind Front',
    44: 'Nailer Top',
    45: 'Nailer Bottom',
    46: 'Nailer Center',
    47: 'Frame Inner Stile',
    48: 'Frame Inner Rail',
    49: 'Frame Left Stile',
    50: 'Frame Right Stile',
    51: 'Frame Bottom Rail',
    52: 'Frame Top Rail',
    53: 'Frame Panel',
    54: 'Flap',
    55: 'Face Frame Left Stile',
    56: 'Face Frame Right Stile',
    57: 'Face Frame Bottom Rail',
    58: 'Face Frame Top Rail',
    59: 'Face Frame Inner Stile',
    60: 'Face Frame Inner Rail',
    61: 'Face Frame',
}


# New in interiorcad 2020 F3
# Original string resources for getConstructionGroupComponentName: XG Cabinet/.../11106 Cabinet Construction Group Component Description.vwstrings
# The order of the CONSTRUCTION_GROUP_COMPONENT_NAMES is different from 11106 Cabinet Construction Group Component Description.vwstrings!
@functools.lru_cache(None)
def getConstructionGroupComponentName(cgcid):
    if hasattr(_interiorcadlocalization, 'getConstructionGroupComponentName'):
        return _interiorcadlocalization.getConstructionGroupComponentName(cgcid)
    elif cgcid in CONSTRUCTION_GROUP_COMPONENT_NAMES:
        return CONSTRUCTION_GROUP_COMPONENT_NAMES[cgcid]
    else:
        return f'CGC Name {cgcid}'  # We cannot translate, as an older interiorcad would not have the translation
