# -*- coding: utf-8 -*-

# Copyright 2024, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import logging

import interiorcad.backend.exportdatasafe
from interiorcad.backend.datatracker.exportdatacollector import ExportDataCollector
from interiorcad.backend.localization import CONSTRUCTION_GROUP_COMPONENT_NAMES, getConstructionGroupComponentName, getLocalizedString, COMMON_MESSAGES_RESOURCEGROUP


class LoggingOfExcludedConstructionGroupComponents:
    # Functionality basically like CustomExport
    def createLoggingOfExcludedConstructionGroupComponents(self, **keywords):
        excludedConstructionGroupComponents = self.getExcludedConstructionGroupComponentsForExport(**keywords)
        if excludedConstructionGroupComponents and interiorcad.backend.exportdatasafe.FIRST_EXPORT:
            message = getLocalizedString(COMMON_MESSAGES_RESOURCEGROUP, 2, "The following construction group components are filtered according to the Construction Groups filter of the Production settings (Output): {excludedConstructionGroupComponents}.")
            logging.info(message.format(excludedConstructionGroupComponents=excludedConstructionGroupComponents))

    def getExcludedConstructionGroupComponentsForExport(self, **keywords):
        if 'excludedConstructionGroups' in keywords and keywords['excludedConstructionGroups']:
            return self.filterConstructionGroupComponentIDsForExport(filterFunction=(lambda mapping, cg: mapping.get(str(cg), None) is not None), **keywords)

    def filterConstructionGroupComponentIDsForExport(self, **keywords):
        filterFunction = keywords['filterFunction']

        cgcNameMappingFromLocalization = self.getMappingFromLocalization()  # Localized dictionary of all cgcs {id: 'name'}
        cgcNameMappingFromConfiguration = {entry.get('id'): entry.get('name') for entry in keywords['excludedConstructionGroups']}  # Localized dictionary of excluded cgcs {id: 'name'}

        filteredConstructionGroupComponents = set()
        for cgc in self.getConstructionGroupComponentsOfScope(**keywords):  # All cgcids of the included construction group components of the export
            if filterFunction(cgcNameMappingFromConfiguration, cgc):  # Depending on the filterFunction the included or excluded cgc names are added to the set of filtered construction group components
                filteredConstructionGroupComponents.add(cgcNameMappingFromLocalization.get(str(cgc), cgcNameMappingFromConfiguration.get(str(cgc))))

        return ', '.join(filteredConstructionGroupComponents)

    def getMappingFromLocalization(self):
        mapping = {key: getConstructionGroupComponentName(key) for key in CONSTRUCTION_GROUP_COMPONENT_NAMES}
        return mapping

    def getConstructionGroupComponentsOfScope(self, **keywords):
        constructionGroupComponents = {ExportDataCollector.getConstructionGroupComponentID(uuid) for uuid, _ in ExportDataCollector.getUnfiltertedAllCustomPartUUIDsAndCounts()}
        return constructionGroupComponents
