# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.geometry import isNearlyEqual
from interiorcad.interface.geometry.vector import Vector


class LineMachiningAnalyzer:
    def __filterPolygonalCase(self, dadorabbet, segment, expectedDistanceFromLineToSegment):
        dadorabbetDirectionVector = (dadorabbet.getEndPoint() - dadorabbet.getStartPoint()).normalized()
        dadorabbetStartPosition = dadorabbet.getStartPoint()
        dadorabbetStartPosition.z = 0
        dadorabbetEndPosition = dadorabbet.getEndPoint()
        dadorabbetEndPosition.z = 0

        segmentDirectionPoint = (segment.end.position - segment.start.position)
        segmentDirectionVector = Vector(segmentDirectionPoint.x, segmentDirectionPoint.y, 0).normalized()
        segmentStartPosition = Vector(segment.start.position.x, segment.start.position.y, 0)
        segmentEndPosition = Vector(segment.end.position.x, segment.end.position.y, 0)

        if isNearlyEqual((dadorabbetStartPosition - segmentStartPosition).magnitude(), expectedDistanceFromLineToSegment):
            good = dadorabbetDirectionVector == segmentDirectionVector
        elif isNearlyEqual((dadorabbetStartPosition - segmentEndPosition).magnitude(), expectedDistanceFromLineToSegment):
            good = dadorabbetDirectionVector == - segmentDirectionVector
        elif isNearlyEqual((dadorabbetEndPosition - segmentStartPosition).magnitude(), expectedDistanceFromLineToSegment):
            good = dadorabbetDirectionVector == - segmentDirectionVector
        elif isNearlyEqual((dadorabbetEndPosition - segmentEndPosition).magnitude(), expectedDistanceFromLineToSegment):
            good = dadorabbetDirectionVector == segmentDirectionVector
        else:
            good = True

        return good

    def generateFoundSegmentsAtDistance(self, linemachining, workpieceShape, expectedDistanceFromLineToSegment):
        segments = workpieceShape.getSegments()
        potentialSegments = filter(lambda segment: not segment.hasOverlappingPoints() and isNearlyEqual(segment.distance(linemachining.matrix.origin), expectedDistanceFromLineToSegment) and isNearlyEqual(segment.distance(linemachining.getEndPoint()), expectedDistanceFromLineToSegment), segments)

        if not workpieceShape.isRectangular():
            potentialSegments = filter(lambda segment: self.__filterPolygonalCase(linemachining, segment, expectedDistanceFromLineToSegment), potentialSegments)

        return potentialSegments

    def isRabbet(self, dadorabbet, workpieceShape):
        widthHalf = dadorabbet.width / 2
        return any(self.generateFoundSegmentsAtDistance(dadorabbet, workpieceShape, widthHalf))

    def isDado(self, dadorabbet, workpieceShape):
        return not self.isRabbet(dadorabbet, workpieceShape)
