# -*- coding: utf-8 -*-

# Copyright 2015-2017, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

from interiorcad.backend.ncexportmigrated.nclinesegment import NCLineSegment
from interiorcad.interface.geometry.point import Point
from interiorcad.backend.ncexportmigrated.ncradiussegment import NCRadiusSegment
from interiorcad.interface.geometry.cornervertex import CornerVertex
from interiorcad.interface.geometry.radiusvertex import RadiusVertex


def generateTwoSegmentsCCW(pocket):
    position = pocket.position
    radius = pocket.diameter / 2

    return (
        NCRadiusSegment(startPt=CornerVertex(position + Point(radius, 0)), radiusPt=RadiusVertex(position + Point(0, radius), radius=radius), endPt=CornerVertex(position + Point(-radius, 0))),
        NCRadiusSegment(startPt=CornerVertex(position + Point(-radius, 0)), radiusPt=RadiusVertex(position + Point(0, -radius), radius=radius), endPt=CornerVertex(position + Point(radius, 0))),
    )


def generateTwoSegmentsCCWWithApproach(pocket):
    position = pocket.position
    radius = pocket.diameter / 2

    return (
        NCLineSegment(CornerVertex(position), CornerVertex(position + Point(radius, 0))),
        NCRadiusSegment(startPt=CornerVertex(position + Point(radius, 0)), radiusPt=RadiusVertex(position + Point(0, radius), radius=radius), endPt=CornerVertex(position + Point(-radius, 0))),
        NCRadiusSegment(startPt=CornerVertex(position + Point(-radius, 0)), radiusPt=RadiusVertex(position + Point(0, -radius), radius=radius), endPt=CornerVertex(position + Point(radius, 0))),
    )


def generateTwoSegmentsCW(pocket):
    position = pocket.position
    radius = pocket.diameter / 2

    return (
        NCRadiusSegment(startPt=CornerVertex(position + Point(radius, 0)), radiusPt=RadiusVertex(position + Point(0, -radius), radius=radius), endPt=CornerVertex(position + Point(-radius, 0))),
        NCRadiusSegment(startPt=CornerVertex(position + Point(-radius, 0)), radiusPt=RadiusVertex(position + Point(0, radius), radius=radius), endPt=CornerVertex(position + Point(radius, 0))),
    )


def generateTwoSegmentsCWWithApproach(pocket):
    position = pocket.position
    radius = pocket.diameter / 2

    return (
        NCLineSegment(CornerVertex(position), CornerVertex(position + Point(radius, 0))),
        NCRadiusSegment(startPt=CornerVertex(position + Point(radius, 0)), radiusPt=RadiusVertex(position + Point(0, -radius), radius=radius), endPt=CornerVertex(position + Point(-radius, 0))),
        NCRadiusSegment(startPt=CornerVertex(position + Point(-radius, 0)), radiusPt=RadiusVertex(position + Point(0, radius), radius=radius), endPt=CornerVertex(position + Point(radius, 0))),
    )


class MockPocket:
    def __init__(self, position, diameter):
        self.position = position
        self.diameter = diameter


class Tests(unittest.TestCase):
    def setUp(self):
        self.pocket = MockPocket(position=Point(0, 0), diameter=20)

    def testCCW(self):
        expected = (
            NCRadiusSegment(startPt=CornerVertex(Point(10, 0)), radiusPt=RadiusVertex(Point(0, 10), radius=10), endPt=CornerVertex(Point(-10, 0))),
            NCRadiusSegment(startPt=CornerVertex(Point(-10, 0)), radiusPt=RadiusVertex(Point(0, -10), radius=10), endPt=CornerVertex(Point(10, 0))),
        )
        self.assertEqual(expected, generateTwoSegmentsCCW(self.pocket))

    def testCW(self):
        expected = (
            NCRadiusSegment(startPt=CornerVertex(Point(10, 0)), radiusPt=RadiusVertex(Point(0, -10), radius=10), endPt=CornerVertex(Point(-10, 0))),
            NCRadiusSegment(startPt=CornerVertex(Point(-10, 0)), radiusPt=RadiusVertex(Point(0, 10), radius=10), endPt=CornerVertex(Point(10, 0))),
        )
        self.assertEqual(expected, generateTwoSegmentsCW(self.pocket))
