# -*- coding: utf-8 -*-

# Copyright 2011-2015, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest


class PostProcessors:
    def __init__(self, *args):
        self.processors = list(args)

    def append(self, processor):
        if processor:
            self.processors.append(processor)

    def extend(self, processors):
        self.processors.extend(processors)

    def process(self, surface):
        for processor in self.processors:
            processor.process(surface)


class TestProcessor:
    def process(self, surface):
        surface.processed_by_testprocessor = 'TestProcessor'


class TestProcessor2:
    def process(self, surface):
        surface.processed_by_testprocessor = 'TestProcessor2'


class Test(unittest.TestCase):
    class TestSurface:
        pass

    def setUp(self):
        self.surface = self.TestSurface()
        self.postProcessor = PostProcessors()

    def testDefaultSurfacePostProcessorHasNoProcessors(self):
        self.assertListEqual(list(), self.postProcessor.processors)

    def testPostProcessorWithOneProcessor(self):
        self.postProcessor.append(TestProcessor())
        self.postProcessor.process(self.surface)
        self.assertTrue(hasattr(self.surface, 'processed_by_testprocessor'))

    def testPostProcessorWithTwoProcessors(self):
        self.postProcessor.append(TestProcessor())
        self.postProcessor.append(TestProcessor2())
        self.postProcessor.process(self.surface)
        self.assertEqual('TestProcessor2', self.surface.processed_by_testprocessor)

    def testPostProcessorWithTwoProcessors2(self):
        self.postProcessor.append(TestProcessor2())
        self.postProcessor.append(TestProcessor())
        self.postProcessor.process(self.surface)
        self.assertEqual('TestProcessor', self.surface.processed_by_testprocessor)

    def testCanExtendPostProcessors(self):
        self.postProcessor.extend([TestProcessor(), TestProcessor2()])
        self.assertEqual(2, len(self.postProcessor.processors))
