# -*- coding: utf-8 -*-

# Copyright 2011-2017, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


import unittest

from interiorcad.interface.geometry.point import Point
from interiorcad.interface.geometry.rectangle import Rectangle


class AddSurfaceDeltaToDados:
    def process(self, surface):
        self.surface = surface
        self.addDistancesToFinishedSizeBoundsToDados()

    def addDistancesToFinishedSizeBoundsToDados(self):
        left = 0
        bottom = 0
        right = self.surface.sawnSize.x + 2 * self.surface.sizingAddition
        top = self.surface.sawnSize.y + 2 * self.surface.sizingAddition
        for dado in self.surface.dadosVertical:
            leftDelta = min(dado.getStartPoint().x - left, dado.getEndPoint().x - left)
            rightDelta = min(right - dado.getStartPoint().x, right - dado.getEndPoint().x)
            bottomDelta = min(dado.getStartPoint().y - bottom, dado.getEndPoint().y - bottom)
            topDelta = min(top - dado.getStartPoint().y, top - dado.getEndPoint().y)
            dado.deltaToSurface = Rectangle(left=leftDelta, right=rightDelta, bottom=bottomDelta, top=topDelta)


class AddSurfaceDeltaToDadosTests(unittest.TestCase):
    class TestSurfaceWithOneDado:
        class TestDado:
            def getStartPoint(self):
                return Point(10, 25)

            def getEndPoint(self):
                return Point(95, 190)

        def __init__(self):
            self.sawnSize = Point(100, 200)
            self.sizingAddition = 5
            self.dadosVertical = [self.TestDado()]

    def testSurfaceDeltaShouldBeCorrect(self):
        processor = AddSurfaceDeltaToDados()
        surface = self.TestSurfaceWithOneDado()
        processor.process(surface)
        self.assertEqual(surface.dadosVertical[0].deltaToSurface.left, 10)
        self.assertEqual(surface.dadosVertical[0].deltaToSurface.right, 15)
        self.assertEqual(surface.dadosVertical[0].deltaToSurface.bottom, 25)
        self.assertEqual(surface.dadosVertical[0].deltaToSurface.top, 20)
