# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import logging

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP


class ContourExportFilter:
    def __init__(self, ncexport):
        self.ncexport = ncexport

    def process(self, surface):
        validContours = []

        for contour in surface.getAllContours():
            if self.ncexport.isValidContour(contour=contour):
                validContours.append(contour)
            else:
                self.informAboutNCExportMismatch(surface, contour)

        surface.setAllContours(validContours)

    def informAboutNCExportMismatch(self, surface, contour):
        message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 71, "Suppressing contour, due to mismatch of the selected NC export! Expected NC export: '{name}' Workpiece: {workpiece}, Contour width: {width}, depth: {depth}")
        logging.info(message.format(name=contour.selectedMachine, workpiece=surface.workpieceName, width=contour.width, depth=contour.depth))
