# -*- coding: utf-8 -*-

# Copyright 2011-2017, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.surface.drillingsorter import DrillingSorter


class DrillingsSorter:
    def __init__(self, drillingStartPosition, drillingOrderings):
        self.drillingStartPosition = drillingStartPosition
        self.drillingOrderings = drillingOrderings

    def process(self, surface):
        self.surface = surface

        self.sortVerticalDrillingsAndCenterPunches()
        self.sortHorizontalDrillingsAndCenterPunches()
        self.sortFiveAxisDrillingsAndCenterPunches()

        self.sortVerticalPockets()

    def sortVerticalDrillingsAndCenterPunches(self):
        self.surface.setVerticalDrillingsAndCenterPunches(self.__sortDrillings(self.surface.verticalDrillingsAndCenterPunches))

    def sortHorizontalDrillingsAndCenterPunches(self):
        self.surface.setHorizontalDrillingsAndCenterPunches(self.__sortDrillings(self.surface.horizontalDrillingsAndCenterPunches))

    def sortFiveAxisDrillingsAndCenterPunches(self):
        self.surface.setFiveAxisDrillingsAndCenterPunches(self.__sortDrillings(self.surface.fiveAxisDrillingsAndCenterPunches))

    def sortVerticalPockets(self):
        self.surface.pockets = DrillingSorter.sortDistance(self.surface.pockets, self.drillingStartPosition)

    def __sortDrillings(self, drillings):
        return DrillingSorter.sortByOrderingCriteria(drillings, self.drillingStartPosition, self.drillingOrderings)


# Deprecated form interiorcad 2020 F9 on (as NCExportBase.getPostAssignToolProcessors exists now and the regular implicit call to DrillingsSorter can be used for the same purpose)
class FiveAxisDrillingsSorter(DrillingsSorter):
    def process(self, surface):
        self.surface = surface
        self.sortFiveAxisDrillingsAndCenterPunches()
