# -*- coding: utf-8 -*-

# Copyright 2011-2021, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.surface import Drilling2D, CenterPunch2D, FiveAxisCenterPunch, FiveAxisDrilling


class DrillingsWithToolIDToFiveAxisDrillingsConverter:
    def __init__(self, toolValidator):
        self.toolValidator = toolValidator

    def process(self, surface):
        self.processVertical(surface)
        self.processHorizontal(surface)

    def processVertical(self, surface):
        remain, fiveaxis = self.__splitByExistingToolID(surface, surface.verticalDrillingsAndCenterPunches)
        surface.setVerticalDrillingsAndCenterPunches(remain)
        surface.addFiveAxisDrillings(fiveaxis)

    def processHorizontal(self, surface):
        remain, fiveaxis = self.__splitByExistingToolID(surface, surface.horizontalDrillingsAndCenterPunches)
        surface.setHorizontalDrillingsAndCenterPunches(remain)
        surface.addFiveAxisDrillings(fiveaxis)

    def __splitByExistingToolID(self, surface, drillings):
        remain = []
        fiveaxis = []

        for drilling in drillings:
            if self.toolValidator(tool=drilling.tool):
                assert isinstance(drilling, (Drilling2D, CenterPunch2D)), "The Machining must be either a Drilling2D or a CenterPunch2D"
                if isinstance(drilling, CenterPunch2D):
                    fiveaxis.append(FiveAxisCenterPunch.createFromDrilling(drilling))
                else:
                    fiveaxis.append(FiveAxisDrilling.createFromDrilling(drilling))
            else:
                remain.append(drilling)

        return remain, fiveaxis
