# -*- coding: utf-8 -*-

# Copyright 2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import logging


class LicenseFilter:
    def __init__(self, licenseinfo):
        assert licenseinfo, "Internal Error: no license"
        self.licenseinfo = licenseinfo

    def process(self, surface):
        if not self.licenseinfo.worker:
            surface.machinings = list(self.getNonWorkerLicensedMachinings(surface))

    def getNonWorkerLicensedMachinings(self, surface):
        for machining in surface.getAllMachiningsButSizing():
            potentialError = machining.getStarterError(surface.workpieceName)
            if not potentialError:
                yield machining
            else:
                logging.error(potentialError)
