# -*- coding: utf-8 -*-

# Copyright 2011-2016, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


import logging

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP


class NonVerticalDrillingsFilter:
    def __init__(self):
        pass

    def process(self, surface):
        self.surface = surface
        self.filterHorizontalDrillingsByDrillingDiameters()
        self.filterFiveAxisDrillingsByDrillingDiameters()

    def filterDrillingsByDiameters(self, drillings, errorMessage):
        for drilling in drillings:
            if hasattr(drilling, 'tool') and drilling.tool is not None:
                yield drilling
            else:
                logging.warning(errorMessage.format(self.surface.workpieceName, drilling.diameter))

    def filterHorizontalDrillingsByDrillingDiameters(self):
        errorMessage = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 46, "Suppressing horizontal drilling, as no tool was found for it. Workpiece: {} Diameter: {}")
        self.surface.setHorizontalDrillings(self.filterDrillingsByDiameters(self.surface.getHorizontalDrillings(), errorMessage))

    def filterFiveAxisDrillingsByDrillingDiameters(self):
        errorMessage = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 47, "Suppressing five-axis drilling, as no tool was found for it. Workpiece: {} Diameter: {}")
        self.surface.setFiveAxisDrillings(self.filterDrillingsByDiameters(self.surface.getFiveAxisDrillings(), errorMessage))
