# -*- coding: utf-8 -*-

# Copyright 2016-2020, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


from interiorcad.interface.surface.pocket2d import VerticalPocket2D, HorizontalPocket2D


class PocketFilter:
    def __init__(self, machineConfiguration):
        self.machineConfiguration = machineConfiguration

    def process(self, surface):
        self.pockets = []

        self.processVertical(surface)
        self.processHorizontal(surface)

        surface.setPockets(self.pockets)

    def processVertical(self, surface):
        self.drillings = []
        for drilling in surface.getVerticalDrillings():
            self.processOneDrilling(drilling, surface, VerticalPocket2D)
        surface.setVerticalDrillings(self.drillings)

    def processHorizontal(self, surface):
        self.drillings = []
        for drilling in surface.getHorizontalDrillings():
            self.processOneDrilling(drilling, surface, HorizontalPocket2D)
        surface.setHorizontalDrillings(self.drillings)

    def processOneDrilling(self, drilling, surface, cls):
        if hasattr(drilling, 'tool') and drilling.tool is not None:
            self.drillings.append(drilling)
        else:
            pocket = cls.createFromDrilling(drilling)
            pocket.assignTool(surface, self.machineConfiguration)
            if pocket.tool:
                self.pockets.append(pocket)
            else:
                self.drillings.append(drilling)
