# -*- coding: utf-8 -*-

# Copyright 2011-2016, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import logging
import unittest.mock

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP


class RabbetToolFilter:
    def process(self, surface):
        validRabbets = []

        for rabbet in surface.rabbetsVertical:
            if rabbet.tool:
                validRabbets.append(rabbet)
            else:
                self.informAboutUnsupportedRabbet(surface)

        surface.rabbetsVertical = validRabbets

    def informAboutUnsupportedRabbet(self, surface):
        message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 44, "Suppressing rabbet, as no tool were found for rabbets! Workpiece: {workpiece}")
        logging.warning(message.format(workpiece=surface.workpieceName))


class Tests(unittest.TestCase):
    def setUp(self):
        self.filter = RabbetToolFilter()
        self.surface = unittest.mock.Mock()
        self.surface.rabbetsVertical = []

    def testNoRabbetShouldNotLogAnything(self):
        with unittest.mock.patch('logging.warning') as patcher:
            self.filter.process(self.surface)
            self.assertFalse(patcher.called)

    def testRabbetWithoutToolShouldWarnAndDiscardRabbet(self):
        rabbet = unittest.mock.Mock()
        rabbet.tool = None
        self.surface.rabbetsVertical.append(rabbet)

        with unittest.mock.patch('logging.warning') as patcher:
            self.filter.process(self.surface)
            self.assertTrue(patcher.called)

        self.assertEqual([], self.surface.rabbetsVertical)

    def testRabbetWithToolShouldNotWarnAndBeKept(self):
        rabbet = unittest.mock.Mock()
        rabbet.tool = unittest.mock.Mock()
        self.surface.rabbetsVertical.append(rabbet)

        with unittest.mock.patch('logging.warning') as patcher:
            self.filter.process(self.surface)
            self.assertFalse(patcher.called)

        self.assertEqual([rabbet], self.surface.rabbetsVertical)
