# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP
from interiorcad.interface.surface.surfaceapproach import SurfaceApproach


class SizingApproachProcessor:
    def __init__(self, minimumSegmentLength, searchMaxY):
        self.minimumSegmentLength = minimumSegmentLength
        self.searchMaxY = searchMaxY

    def process(self, surface):
        self.surface = surface
        self.defineApproach()

    def defineApproach(self):
        if self.surface.hasSizing():
            approach = SurfaceApproach(self.surface, self.searchMaxY)
            approach.setApproach(self.minimumSegmentLength)
            self.logSuppressedSizing(approach.discardedSizings)

    def logSuppressedSizing(self, sizings):
        if sizings:
            raise Exception(getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 8, "Suppressing sizing due to missing linear contour segment. Workpiece: %s") % self.surface.workpieceName)
