# -*- coding: utf-8 -*-

# Copyright 2020-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP
from interiorcad.interface.surface.surfaceapproach import SurfaceApproach


class SizingThreeSideContourProcessor():
    def __init__(self, isOriginFront):
        self.isOriginFront = isOriginFront

    def process(self, surface):
        sizing = surface.sizing
        if sizing:
            approach = SurfaceApproach(surface=surface, searchMaxY=not self.isOriginFront)
            extremeSegment = approach.getSegmentOfExtremeYValue(approach)
            approach.setApproachAtVertex(extremeSegment.end if extremeSegment else None)

            if sizing.isValid():
                sizing.polyline.vertices[-1].visible = False
            else:
                # FIXME IT-251: I18N/L10N or change the implementation? -- NG
                raise Exception(getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, None, "Suppressing three side sizing, as it could not be created. Workpiece: {workpiece}").format(workpiece=surface.workpieceName))
