# -*- coding: utf-8 -*-

# Copyright 2011-2020, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import logging

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP


class CenterPunchFilter:
    # Up to interiorcad 2020 F7 depth was used in __init__ for setting the depth of CenterPunches.
    # From interiorcad 2020 F8 on, setting the depth is done in interiorcad.interface.surface.centerpunch2D.CenterPunch2D.setConfiguratedDepth
    def process(self, surface):
        self.validCenterPunches = []

        for centerPunch in self.getCenterPunches(surface):
            self.processCenterPunch(centerPunch, surface)

        self.setCenterPunches(surface, self.validCenterPunches)

    def processCenterPunch(self, centerPunch, surface):
        if hasattr(centerPunch, 'tool') and centerPunch.tool is not None:
            self.validCenterPunches.append(centerPunch)
        else:
            self.logSuppressedCenterPunch(centerPunch, surface)

    def logSuppressedCenterPunch(self, suppressedCenterPunch, surface):
        errorMessage = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 33, "Suppressing {machining} due to unsupported diameter! (Workpiece: {workpiece} Diameter: {diameter})")
        logging.warning(errorMessage.format(machining=self.getMachiningName(), workpiece=surface.workpieceName, diameter=suppressedCenterPunch.diameter))


class VerticalCenterPunchFilter(CenterPunchFilter):
    def getCenterPunches(self, surface):
        return surface.getVerticalCenterPunches()

    def setCenterPunches(self, surface, centerPunches):
        surface.setVerticalCenterPunches(centerPunches)

    def getMachiningName(self):
        return getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 34, "vertical center punch")


class HorizontalCenterPunchFilter(CenterPunchFilter):
    def getCenterPunches(self, surface):
        return surface.getHorizontalCenterPunches()

    def setCenterPunches(self, surface, centerPunches):
        surface.setHorizontalCenterPunches(centerPunches)

    def getMachiningName(self):
        return getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 35, "horizontal center punch")


class FiveAxisCenterPunchFilter(CenterPunchFilter):
    def getCenterPunches(self, surface):
        return surface.getFiveAxisCenterPunches()

    def setCenterPunches(self, surface, centerPunches):
        surface.setFiveAxisCenterPunches(centerPunches)

    def getMachiningName(self):
        return getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 36, "five-axis center punch")
