# -*- coding: utf-8 -*-

# Copyright 2011-2016, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import logging

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP


class VerticalDrillingsFilter:
    def __init__(self, allowSmallDrillingsWithoutToolID):
        self.allowSmallDrillingsWithoutToolID = allowSmallDrillingsWithoutToolID

    def process(self, surface):
        self.validVerticalDrillings = []

        for drilling in surface.getVerticalDrillings():
            self.processOneDrilling(drilling, surface)

        surface.setVerticalDrillings(self.validVerticalDrillings)

    def shouldDrillThrough(self, drilling, surface):
        return drilling.depth >= surface.thickness

    def processOneDrilling(self, drilling, surface):
        if hasattr(drilling, 'tool') and drilling.tool is not None:
            self.validVerticalDrillings.append(drilling)
        elif self.allowSmallDrillingsWithoutToolID:
            self.validVerticalDrillings.append(drilling)
            self.informAboutSmallDrillingWithoutToolID(drilling, surface)
        else:
            self.informAboutUnsupportedDrilling(drilling, surface)

    def __logDrilling(self, drilling, surface, loggingLevel, message):
        drillThrough = self.shouldDrillThrough(drilling, surface)
        logging.log(loggingLevel, message.format(workpiece=surface.workpieceName, diameter=drilling.diameter, drillThrough=drillThrough))

    def informAboutUnsupportedDrilling(self, drilling, surface):
        message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 9, "Suppressing vertical drilling due to unsupported diameter! Workpiece: {workpiece}, diameter: {diameter}, drill through: {drillThrough}")
        self.__logDrilling(drilling, surface, logging.INFO, message)

    def informAboutSmallDrillingWithoutToolID(self, drilling, surface):
        message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 28, "Exporting vertical drilling without tool ID! Workpiece: {workpiece}, diameter: {diameter}, drill through: {drillThrough}")
        self.__logDrilling(drilling, surface, logging.INFO, message)
