# -*- coding: utf-8 -*-

# Copyright 2011-2015, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import operator
import unittest
import copy


class DataListSorter:
    def __init__(self, indices=None):
        self.sortIndicies = indices if indices is not None else []

    ### IT-138: change Tests, so that this function is not needed any more. -- NG
    def setSortingOrder(self, indices):
        self.sortIndicies = indices

    # Sort in a notation similar to 4D, e.g.: (5, '>', 9, '<', 7, '<', 8, '<')
    def sortList(self, theList):
        sortReversed = False
        if self.sortIndicies:
            for index in reversed(self.sortIndicies):
                if index == '>':
                    sortReversed = False
                elif index == '<':
                    sortReversed = True
                else:
                    theList.sort(key=operator.itemgetter(index), reverse=sortReversed)


class SortingTests(unittest.TestCase):
    def setUp(self):
        self.sorter = DataListSorter()
        self.data = [
            ('Cat', 'Rose', 'Beech'),
            ('Parrot', 'Tulip', 'Walnut'),
            ('Dog', 'Lily', 'Pine'),
            ('Mouse', 'Lily', 'Oak'),
        ]

    def testWithoutSortingOrderNoSortingShouldBeDone(self):
        expectedData = copy.copy(self.data)
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)

    def testIndexZeroShouldSortTheLeftmostColumnInAscendingOrder(self):
        expectedData = [
            ('Cat', 'Rose', 'Beech'),
            ('Dog', 'Lily', 'Pine'),
            ('Mouse', 'Lily', 'Oak'),
            ('Parrot', 'Tulip', 'Walnut'),
        ]
        self.sorter.setSortingOrder((0,))
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)

    def testGreaterSignShouldSortInAscendingOrder(self):
        expectedData = [
            ('Cat', 'Rose', 'Beech'),
            ('Dog', 'Lily', 'Pine'),
            ('Mouse', 'Lily', 'Oak'),
            ('Parrot', 'Tulip', 'Walnut'),
        ]
        self.sorter.setSortingOrder((0, '>'))
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)

    def testLesserSignShouldSortInAscendingOrder(self):
        expectedData = [
            ('Parrot', 'Tulip', 'Walnut'),
            ('Mouse', 'Lily', 'Oak'),
            ('Dog', 'Lily', 'Pine'),
            ('Cat', 'Rose', 'Beech'),
        ]
        self.sorter.setSortingOrder((0, '<'))
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)

    def testSortingTwoColumnsShouldSortInAscendingOrder(self):
        expectedData = [
            ('Dog', 'Lily', 'Pine'),
            ('Mouse', 'Lily', 'Oak'),
            ('Cat', 'Rose', 'Beech'),
            ('Parrot', 'Tulip', 'Walnut'),
        ]
        self.sorter.setSortingOrder((1, 0))
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)

    def testSortingTwoColumnsInAscendingOrderShouldSortInAscendingOrder(self):
        expectedData = [
            ('Dog', 'Lily', 'Pine'),
            ('Mouse', 'Lily', 'Oak'),
            ('Cat', 'Rose', 'Beech'),
            ('Parrot', 'Tulip', 'Walnut'),
        ]
        self.sorter.setSortingOrder((1, '>', 0, '>'))
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)

    def testSortingTwoColumnsOneAscendignOneDescendingShouldSortAsExpected(self):
        expectedData = [
            ('Mouse', 'Lily', 'Oak'),
            ('Dog', 'Lily', 'Pine'),
            ('Cat', 'Rose', 'Beech'),
            ('Parrot', 'Tulip', 'Walnut'),
        ]
        self.sorter.setSortingOrder((1, '>', 0, '<'))
        self.sorter.sortList(self.data)
        self.assertEqual(expectedData, self.data)
