# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


from interiorcad.backend.surfacecreator.mainsurfacecreator import MainSurfaceCreator
from interiorcad.backend.surfacecreator.oppositesurfacecreator import OppositeSurfaceCreator
from interiorcad.backend.surfacecreator.sizingsurfacecreator import SizingSurfaceCreator
from interiorcad.backend.surfacecreator.surfacecreationstrategy import SurfaceCreationStrategy
from interiorcad.backend.surfacecreator.surfacesidedecider import SurfaceSideDecider
from interiorcad.backend.sizingcreator import SizingCreator
from interiorcad.backend.surfacedimensioncreator import SurfaceDimensionCreator
from interiorcad.backend.postprocessors import PostProcessors
from interiorcad.backend.surfacesizingcreator import SurfaceSizingCreator
from interiorcad.backend.workpiece.reader import WorkpieceReader
from interiorcad.backend.surfacecreator.bothsidedsurfacecreator import BothSidedSurfaceCreator


class SurfaceCreatorOptions:
    def __init__(self, surfaceOrigin, grainConsiderationMode, shouldAllwaysCreateMainSide, allowHorizontalMachiningsOnMainSide):
        self.surfaceOrigin = surfaceOrigin
        self.grainConsiderationMode = grainConsiderationMode
        self.shouldAllwaysCreateMainSide = shouldAllwaysCreateMainSide
        self.allowHorizontalMachiningsOnMainSide = allowHorizontalMachiningsOnMainSide


class SurfaceCreator:
    def __init__(self, workpiece, config, sizeStrategy, sizingStrategy, options):
        self.reader = WorkpieceReader(workpiece)
        self.surfaceSideDecider = SurfaceSideDecider(workpiece, sizingStrategy, options.shouldAllwaysCreateMainSide, options.allowHorizontalMachiningsOnMainSide)
        self.postProcessor = PostProcessors()
        self.dimensionCreator = SurfaceDimensionCreator(self.reader, sizeStrategy, self.surfaceSideDecider.needsMain(), self.surfaceSideDecider.needsOpposite(), config.sizingAddition)
        self.options = options

        sizingCreator = SizingCreator(self.reader, config.sizingAddition)
        self.sizingCreator = SurfaceSizingCreator(sizingStrategy, sizingCreator, self.surfaceSideDecider)

    def setPostProcessor(self, postProcessor):
        self.postProcessor = postProcessor

    def createSurfaces(self):
        strategy = SurfaceCreationStrategy(self.surfaceSideDecider, self)
        return strategy.create()

    def createMain(self):
        creator = MainSurfaceCreator(self.reader, self.surfaceSideDecider, self.dimensionCreator, self.sizingCreator, self.postProcessor, self.options)
        return creator.create()

    def createOpposite(self):
        creator = OppositeSurfaceCreator(self.reader, self.surfaceSideDecider, self.dimensionCreator, self.sizingCreator, self.postProcessor, self.options)
        return creator.create()

    def createSizing(self):
        creator = SizingSurfaceCreator(self.reader, self.dimensionCreator, self.sizingCreator, self.postProcessor, self.options)
        return creator.create()

    def createBothSided(self):
        creator = BothSidedSurfaceCreator(self.reader, self.surfaceSideDecider, self.dimensionCreator, self.sizingCreator, self.postProcessor, self.options)
        return creator.create()

    def needsSizing(self):
        return self.surfaceSideDecider.needsSizing()

    def needsMain(self):
        return self.surfaceSideDecider.needsMain()

    def needsOpposite(self):
        return self.surfaceSideDecider.needsOpposite()
