# -*- coding: utf-8 -*-

# Copyright 2011-2021, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.backend.surfacecreator.surfacecreatorbase import BaseSurfaceCreator
from interiorcad.interface.surface import SURFACE_SIDE_TYPE_OPPOSITE
from interiorcad.interface.surface.machiningconverter import MachiningConverter


class OppositeSurfaceCreator(BaseSurfaceCreator):
    def __init__(self, reader, surfaceSideDecider, dimensionCreator, sizingCreator, postProcessor, options):
        super().__init__(reader, dimensionCreator, sizingCreator, postProcessor, options)
        self.surfaceSideDecider = surfaceSideDecider

    def getSideType(self):
        return SURFACE_SIDE_TYPE_OPPOSITE

    def writeMachinings(self, surface):
        machinings = self.reader.getAllMachiningsFromBottomUnconverted()
        if self.__needsHorizontalMachinings():
            machinings.extend(self.reader.getAllHorizontalMachiningsUnconverted())
        machinings2D = MachiningConverter(self.reader.getFinishedSizedShape()).convertMachinings(machinings)
        surface.machinings.extend(machinings2D)

    def __needsHorizontalMachinings(self):
        return self.surfaceSideDecider.needsHorizontalMachiningsOnOpposite()

    def getDimensionData(self):
        return self.dimensionCreator.createOpposite()

    def getSizingData(self):
        return self.sizingCreator.createOpposite()

    def isOppositeSide(self):
        return True
