# -*- coding: utf-8 -*-

# Copyright 2011-2020, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


from interiorcad.backend.surfacedimensioncreator.surfacedimension import SurfaceDimension
from interiorcad.backend.workpiececreationstrategy.constants import SizeMode


class SurfaceDimensionCreator:
    def __init__(self, workpieceReader, strategy, needsMain, needsOpposite, sizingAddition):
        self.strategy = strategy
        self.workpieceReader = workpieceReader
        self.sizingAddition = sizingAddition
        self.needsMain = needsMain
        self.needsOpposite = needsOpposite

    def createMain(self):
        sizingMode = self.strategy.getMainSizeMode(self.needsOpposite)
        return self.__create(sizingMode)

    def createOpposite(self):
        sizingMode = self.strategy.getOppositeSizeMode(self.needsMain)
        return self.__create(sizingMode)

    def createSizing(self):
        sizingMode = self.strategy.getSizingSizeMode()
        return self.__create(sizingMode)

    def createCuttingList(self):
        sizingMode = self.strategy.getCuttingListSizeMode()
        return self.__create(sizingMode)

    def createWorkpieceFilterSize(self):
        sizingMode = self.strategy.getSawnSizeMode()
        return self.__create(sizingMode)

    def createFinishedSize(self):
        sizingMode = SizeMode.FINISHED_SIZE
        return self.__create(sizingMode)

    def createFinishedSizeWithAddition(self):
        sizingMode = SizeMode.FINISHED_SIZE_WITH_ADDITION
        return self.__create(sizingMode)

    def createSawnSize(self):
        sizingMode = SizeMode.SAWN_SIZE
        return self.__create(sizingMode)

    def createSawnSizeWithAddition(self):
        sizingMode = SizeMode.SAWN_SIZE_WITH_ADDITION
        return self.__create(sizingMode)

    def __create(self, sizingMode):
        surfaceDimension = SurfaceDimension()
        if sizingMode == SizeMode.SAWN_SIZE_WITH_ADDITION:
            surfaceDimension.size = self.workpieceReader.getSawnSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getFinishedSizeAddition()
            surfaceDimension.sizingAddition = self.sizingAddition
        elif sizingMode == SizeMode.SAWN_SIZE:
            surfaceDimension.size = self.workpieceReader.getSawnSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getFinishedSizeAddition()
        elif sizingMode == SizeMode.SAWN_SIZE_WITH_JOINTING:
            surfaceDimension.size = self.workpieceReader.getJointingSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getJointingSizeAddition(self.workpieceReader.getJointingSizingBoundsFromWorkpiece())
        elif sizingMode == SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION:
            surfaceDimension.size = self.workpieceReader.getJointingSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getJointingSizeAddition(self.workpieceReader.getJointingSizingBoundsFromWorkpiece())
            surfaceDimension.sizingAddition = self.sizingAddition
        elif sizingMode == SizeMode.FINISHED_SIZE:
            surfaceDimension.size = self.workpieceReader.getFinishedSize()
        elif sizingMode == SizeMode.FINISHED_SIZE_WITH_ADDITION:
            surfaceDimension.size = self.workpieceReader.getFinishedSize()
            surfaceDimension.sizingAddition = self.sizingAddition
        elif sizingMode == SizeMode.PRELIMINARY_RECTANGULAR_SIZE:
            surfaceDimension.size = self.workpieceReader.getSawnSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getFinishedSizeAddition()
            surfaceDimension.sizingAddition = self.sizingAddition
        elif sizingMode == SizeMode.FINAL_SIZING_SIZE:
            surfaceDimension.size = self.workpieceReader.getSawnSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getFinishedSizeAddition()
            surfaceDimension.sizingAddition = self.sizingAddition / 2
        elif sizingMode == SizeMode.FINAL_SIZING_SIZE_WITH_JOINTING:
            surfaceDimension.size = self.workpieceReader.getJointingSizeFromWorkpiece()
            surfaceDimension.additionForEdges = self.workpieceReader.getJointingSizeAddition(self.workpieceReader.getJointingSizingBoundsFromWorkpiece())
            surfaceDimension.sizingAddition = self.sizingAddition / 2
        return surfaceDimension
