# -*- coding: utf-8 -*-

# Copyright 2011-2014, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest


# TODO: would it be more intelligent to have a similar function that eliminates consecutive empty lines and leaves only one empty line. That would perhaps limit tricks like lines="blabla"; if lines: return lines -- NG (IT-196)
def joinIfNotNone(separator, *args):
    result = separator.join(filter(lambda line: line is not None, args))
    if result == "" and all((element is None for element in args)):
        result = None
    return result


class Tests(unittest.TestCase):
    SEPARATOR = ':'

    def testNoElementShouldReturnNone(self):
        self.assertEqual(None, joinIfNotNone(self.SEPARATOR))

    def testOneElementShouldReturnAStringWithoutSeparator(self):
        self.assertEqual('test', joinIfNotNone(self.SEPARATOR, 'test'))

    def testTwoElementsShouldReturnAStringWithOneSeparator(self):
        self.assertEqual('foo:bar', joinIfNotNone(self.SEPARATOR, 'foo', 'bar'))

    def testThreeElementsShouldReturnAStringWithTwoSeparators(self):
        self.assertEqual('bear:cat:dog', joinIfNotNone(self.SEPARATOR, 'bear', 'cat', 'dog'))

    def testThreeElementsIncludingNoneShouldReturnWithoutTheNone(self):
        self.assertEqual('cat:dog', joinIfNotNone(self.SEPARATOR, 'cat', None, 'dog'))

    def testEmptyStringAreAllowed(self):
        self.assertEqual('cat::dog', joinIfNotNone(self.SEPARATOR, 'cat', '', 'dog'))

    def testAllNoneShouldReturnNone(self):
        self.assertEqual(None, joinIfNotNone(self.SEPARATOR, None, None, None))
