# -*- coding: utf-8 -*-

# Copyright 2011-2014, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

from interiorcad.interface.geometry.matrix import Matrix
from interiorcad.interface.geometry.point import Point
from interiorcad.backend.workpiece.machining import Machining


class CenterPunch(Machining):
    def __init__(self, uuid=''):
        super().__init__(uuid)
        self.diameter = 0

    def __str__(self):
        result = ' '.join((
            'CenterPunch:',
            super().__str__() + ';',
            'diameter({d:.{cp}f})'.format(d=self.diameter, cp=2),
        ))
        return result

    def getDiameter(self):
        return self.diameter


class CenterPunchTests(unittest.TestCase):
    def setUp(self):
        self.centerPunch = CenterPunch()

    def testDefaultHasZeroDiameter(self):
        self.assertEqual(0, self.centerPunch.getDiameter())

    def testDefaultHasDefaultMatrix(self):
        self.assertEqual(Matrix(), self.centerPunch.getMatrix())

    def testDefaultHasEmptyUUID(self):
        self.assertEqual('', self.centerPunch.uuid)

    def testCanSetDiameter(self):
        self.centerPunch.diameter = 5
        self.assertEqual(5, self.centerPunch.getDiameter())

    def testCanSetMatrix(self):
        matrix = Matrix('u', 'v', 'w', 'origin')
        self.centerPunch.matrix = matrix
        self.assertEqual('u', self.centerPunch.matrix.u)
        self.assertEqual('v', self.centerPunch.matrix.v)
        self.assertEqual('w', self.centerPunch.matrix.w)
        self.assertEqual('origin', self.centerPunch.matrix.origin)

    def testCanSetUUID(self):
        self.centerPunch.uuid = 'NEW_UUID'
        self.assertEqual('NEW_UUID', self.centerPunch.getUUID())

    def testCanSetUUIDInConstructor(self):
        centerPunch = CenterPunch('NEW_UUID')
        self.assertEqual('NEW_UUID', centerPunch.getUUID())

    class TestMatrix:
        def __str__(self):
            return 'M'

    def testStringRepresentationIsAsExpected(self):
        self.centerPunch.matrix = self.TestMatrix()
        expected = 'CenterPunch: Machining {NO_UUID}: matrix(M); diameter(0.00)'
        self.assertEqual(expected, str(self.centerPunch))

    def testStringRepresentationWithUUIDIsAsExpected(self):
        self.centerPunch.matrix = self.TestMatrix()
        self.centerPunch.uuid = '{UUID}'
        expected = 'CenterPunch: Machining {UUID}: matrix(M); diameter(0.00)'
        self.assertEqual(expected, str(self.centerPunch))

    def testMoveCenterPunch(self):
        from interiorcad.interface.geometry.vector import Vector
        self.centerPunch.matrix.origin = Vector(50.0, 60.0, 70.0)
        self.centerPunch.moveBy(Point(10.0, 20))
        self.assertEqual(Vector(60, 80, 70), self.centerPunch.getMatrix().origin)
