# -*- coding: utf-8 -*-

# Copyright 2011-2014, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

from interiorcad.interface.geometry.matrix import Matrix
from interiorcad.interface.geometry.point import Point


class Machining:
    def __init__(self, uuid=''):
        self.uuid = uuid
        self.matrix = Matrix()

    def moveBy(self, delta):
        self.matrix.origin.x += delta.x
        self.matrix.origin.y += delta.y

    def getMatrix(self):
        return self.matrix

    def __str__(self):
        uuidString = '{NO_UUID}'
        if len(self.uuid) > 0:
            uuidString = self.uuid
        result = ' '.join((
            'Machining {}:'.format(uuidString),
            'matrix({m})'.format(m=str(self.matrix))
        ))
        return result

    def getUUID(self):
        return self.uuid


class Tests(unittest.TestCase):
    def setUp(self):
        self.machining = Machining()

    def testDefaultDrillingHasDefaultMatrix(self):
        self.assertEqual(Matrix(), self.machining.getMatrix())

    def testDefaultDrillingHasEmptyUUID(self):
        self.assertEqual('', self.machining.uuid)

    def testCanSetMatrix(self):
        matrix = Matrix('u', 'v', 'w', 'origin')
        self.machining.matrix = matrix
        self.assertEqual('u', self.machining.matrix.u)
        self.assertEqual('v', self.machining.matrix.v)
        self.assertEqual('w', self.machining.matrix.w)
        self.assertEqual('origin', self.machining.matrix.origin)

    def testCanSetUUID(self):
        self.machining.uuid = 'NEW_UUID'
        self.assertEqual('NEW_UUID', self.machining.getUUID())

    def testCanSetUUIDInConstructor(self):
        machining = Machining('NEW_UUID')
        self.assertEqual('NEW_UUID', machining.getUUID())

    class TestMatrix:
        def __str__(self):
            return 'M'

    def testStringRepresentationIsAsExpected(self):
        self.machining.matrix = self.TestMatrix()
        expected = 'Machining {NO_UUID}: matrix(M)'
        self.assertEqual(expected, str(self.machining))

    def testStringRepresentationWithUUIDIsAsExpected(self):
        self.machining.matrix = self.TestMatrix()
        self.machining.uuid = '{UUID}'
        expected = 'Machining {UUID}: matrix(M)'
        self.assertEqual(expected, str(self.machining))

    def testMove(self):
        from interiorcad.interface.geometry.vector import Vector
        self.machining.matrix.origin = Vector(50.0, 60.0, 70.0)
        self.machining.moveBy(Point(10.0, 20))
        self.assertEqual(Vector(60, 80, 70), self.machining.getMatrix().origin)
