# -*- coding: utf-8 -*-

# Copyright 2011-2021, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.backend.workpiece import Workpiece
from interiorcad.backend.workpiece.drilling import Drilling
from interiorcad.backend.workpiece.shape import Shape
from interiorcad.interface.geometry.cornervertex import CornerVertex
from interiorcad.interface.geometry.point import Point
from interiorcad.interface.geometry.polyline import Polyline
from interiorcad.interface.geometry.rectangle import Rectangle
from interiorcad.interface.geometry.vector import Vector


class TestWorkpieces(object):
    @staticmethod
    def createRectangularWithoutDrillings():
        polyline = Polyline()
        polyline.addVertex(CornerVertex(Point(0, 0)))
        polyline.addVertex(CornerVertex(Point(0, 200)))
        polyline.addVertex(CornerVertex(Point(100, 200)))
        polyline.addVertex(CornerVertex(Point(100, 0)))
        polyline.addVertex(CornerVertex(Point(0, 0)))
        finishedSizeShape = Shape(polyline)

        polyline = Polyline()
        polyline.addVertex(CornerVertex(Point(2, 3)))
        polyline.addVertex(CornerVertex(Point(2, 198)))
        polyline.addVertex(CornerVertex(Point(98, 198)))
        polyline.addVertex(CornerVertex(Point(98, 3)))
        polyline.addVertex(CornerVertex(Point(2, 3)))
        sawnSizeShape = Shape(polyline)

        workpiece = Workpiece()
        workpiece.name = 'TestWorkpiece'
        workpiece.thickness = 20
        workpiece.finishedSizeShape = finishedSizeShape
        workpiece.sawnSizeShape = sawnSizeShape
        workpiece.finishedSizeBounds = Rectangle(0, 0, 100, 200)
        workpiece.sawnSizeBounds = Rectangle(2, 3, 98, 198)
        return workpiece

    @staticmethod
    def createRectangularWithVerticalDrillings():
        drillingTop = Drilling()
        drillingTop.matrix.origin = Vector(0, 0, 20)

        drillingBottom = Drilling()
        drillingBottom.matrix.v = Vector(0.00, -1.00, 0.00)
        drillingBottom.matrix.w = Vector(0.00, 0.00, -1.00)
        drillingBottom.matrix.origin = Vector(50, 50, 0)

        workpiece = TestWorkpieces.createRectangularWithoutDrillings()
        workpiece.machinings = [drillingTop, drillingBottom]

        return workpiece

    @staticmethod
    def createRectangularWithDrillingsOnAllSurfaces():
        wp = TestWorkpieces.createRectangularWithVerticalDrillings()

        drillLeft = Drilling()
        drillLeft.matrix.origin = Vector(0, 20, 4)
        drillLeft.matrix.u = Vector(0, 0, -1)
        drillLeft.matrix.w = Vector(1, 0, 0)

        drillRight = Drilling()
        drillRight.matrix.origin = Vector(100, 40, 8)
        drillRight.matrix.u = Vector(0, 0, 1)
        drillRight.matrix.w = Vector(-1, 0, 0)

        drillBack = Drilling()
        drillBack.matrix.origin = Vector(30, 100, 12)
        drillBack.matrix.v = Vector(0, 0, 1)
        drillBack.matrix.w = Vector(0, -1, 0)

        drillFront = Drilling()
        drillFront.matrix.origin = Vector(60, 0, 16)
        drillFront.matrix.v = Vector(0, 0, -1)
        drillFront.matrix.w = Vector(0, 1, 0)

        wp.machinings.extend((drillLeft, drillRight, drillBack, drillFront))

        return wp
