# -*- coding: utf-8 -*-

# Copyright 2011-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


from interiorcad.backend.workpiececreationstrategy.constants import SizeMode


# Please create class only through interiorcad.backend.workpiececreationstrategy.creator.WorkpieceCreationStrategy.createSizeStrategy
class DefaultSizeStrategy:
    def __init__(self, workpiece, configuration):
        self.workpiece = workpiece
        self.configuration = configuration

    def getSawnSizeMode(self):
        # This represents the size of the workpiece as it comes out of the saw and is placed first on the NC machine.
        if self.workpiece.isRectangular() and self.configuration.accurateSaw:
            if self.configuration.jointing:
                sizing = SizeMode.SAWN_SIZE_WITH_JOINTING
            else:
                sizing = SizeMode.SAWN_SIZE
        elif self.configuration.jointing:
            sizing = SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
        else:
            sizing = SizeMode.SAWN_SIZE_WITH_ADDITION
        return sizing

    def getCuttingListSizeMode(self):
        sizing = self.configuration.sizing
        if sizing == SizeMode.NC_COMPATIBLE:
            sizing = self.getSawnSizeMode()
        return sizing

    def getMainSizeMode(self, needsOpposite):
        if self.workpiece.isRectangular() and self.configuration.accurateSaw:
            return SizeMode.FINISHED_SIZE
        elif self.configuration.separateSizing:
            return SizeMode.FINISHED_SIZE
        elif self.workpiece.isRectangular() or not needsOpposite:
            if self.configuration.jointing:
                return SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
            else:
                return SizeMode.SAWN_SIZE_WITH_ADDITION
        else:
            if self.configuration.jointing:
                return SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
            else:
                return SizeMode.PRELIMINARY_RECTANGULAR_SIZE

    def getOppositeSizeMode(self, needsMain):
        if self.configuration.separateSizing:
            return SizeMode.FINISHED_SIZE
        elif self.workpiece.isRectangular():
            if self.configuration.accurateSaw:
                return SizeMode.FINISHED_SIZE
            elif self.configuration.jointing:
                if needsMain:
                    return SizeMode.SAWN_SIZE_WITH_JOINTING
                else:
                    return SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
            else:
                if needsMain:
                    return SizeMode.SAWN_SIZE
                else:
                    return SizeMode.SAWN_SIZE_WITH_ADDITION
        else:
            if self.configuration.accurateSaw:
                if self.configuration.jointing:
                    return SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
                else:
                    return SizeMode.SAWN_SIZE_WITH_ADDITION
            else:
                if needsMain:
                    if self.configuration.jointing:
                        return SizeMode.FINAL_SIZING_SIZE_WITH_JOINTING
                    else:
                        return SizeMode.FINAL_SIZING_SIZE
                else:
                    if self.configuration.jointing:
                        return SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
                    else:
                        return SizeMode.SAWN_SIZE_WITH_ADDITION

    def getSizingSizeMode(self):
        if self.configuration.jointing:
            return SizeMode.SAWN_SIZE_WITH_JOINTING_AND_ADDITION
        else:
            return SizeMode.SAWN_SIZE_WITH_ADDITION
