# -*- coding: utf-8 -*-

# Copyright 2011-2015, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


from interiorcad.backend.workpiececreationstrategy.constants import SizingMode

# Terminology:
# - size: the dimension of the workpiece
# - sizing the dimension/path of the contour used for sizing


# Please create class only through interiorcad.backend.workpiececreationstrategy.creator.WorkpieceCreationStrategy.createSizingStrategy
class DefaultSizingStrategy:
    def __init__(self, workpiece, configuration):
        self.workpiece = workpiece
        self.configuration = configuration

    def needsSizing(self):
        if self.workpiece.isRectangular() and self.configuration.accurateSaw:
            return False
        else:
            return self.configuration.separateSizing

    def getSizingSizingMode(self):
        if self.configuration.jointing and self.workpiece.isPolygonal():
            return SizingMode.JOINT_SIZING
        else:
            return SizingMode.DEFAULT_SIZING

    def getOppositeSizingMode(self, needsMain):
        if self.workpiece.isRectangular():
            if not self.configuration.accurateSaw and self.configuration.jointing and not needsMain and not self.configuration.separateSizing:
                return SizingMode.JOINT_SIZING
            elif not self.configuration.accurateSaw and not self.configuration.separateSizing and not needsMain:
                return SizingMode.DEFAULT_SIZING
        elif self.workpiece.isPolygonal():
            if self.configuration.jointing and not self.configuration.separateSizing:
                return SizingMode.JOINT_SIZING
            elif not self.configuration.separateSizing:
                return SizingMode.DEFAULT_SIZING
        else:
            if not self.configuration.separateSizing:
                return SizingMode.DEFAULT_SIZING

        return SizingMode.NO_SIZING

    def getMainSizingMode(self, needsOpposite):
        needsPreliminarySizing = not self.workpiece.isRectangular() and not self.configuration.separateSizing and needsOpposite
        if self.workpiece.isRectangular() and not self.configuration.separateSizing and self.configuration.accurateSaw:
            return SizingMode.NO_SIZING
        elif self.workpiece.isPolygonal() and self.configuration.jointing and not self.configuration.separateSizing:
            if needsPreliminarySizing:
                if self.configuration.accurateSaw:
                    return SizingMode.NO_SIZING
                else:
                    return SizingMode.PRELIMINARY_JOINT_SIZING
            else:
                return SizingMode.JOINT_SIZING
        elif self.__needsDefaultSizingForMainSide(needsOpposite):
            return SizingMode.DEFAULT_SIZING
        elif needsPreliminarySizing and not self.configuration.accurateSaw:
            return SizingMode.PRELIMINARY_SIZING
        else:
            return SizingMode.NO_SIZING

    def __needsDefaultSizingForMainSide(self, needsOpposite):
        if self.workpiece.isRectangular():
            if not self.configuration.accurateSaw and not self.configuration.separateSizing:
                return True
        elif not self.configuration.separateSizing and not needsOpposite:
            return True
        return False
