# -*- coding: utf-8 -*-

# Copyright 2016-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


import logging

from interiorcad.backend.workpiececreationstrategy.creator import WorkpieceCreationStrategy
from interiorcad.backend.workpiececreationstrategy.constants import SizingMode
from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP


class EmptyWorkpieceFilter:
    def __init__(self, configuration):
        self.configuration = configuration

    def hasSizing(self, workpiece):
        sizingStrategy = WorkpieceCreationStrategy.createSizingStrategy(workpiece, self.configuration)
        return sizingStrategy.needsSizing() or sizingStrategy.getMainSizingMode(False) is not SizingMode.NO_SIZING

    def filterWorkpiece(self, workpiece):
        hasMachinings = any(workpiece.getAllMachinings())
        isWorkpieceEmpty = not hasMachinings and not self.hasSizing(workpiece)

        if isWorkpieceEmpty:
            message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 52, "Suppressing workpiece '{workpiece}' because it has no machinings")
            logging.warning(message.format(workpiece=workpiece.name))

        return not isWorkpieceEmpty
