# -*- coding: utf-8 -*-

# Copyright 2016-2017, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


import logging

from interiorcad.backend.localization import getLocalizedString, NCEXPORT_MESSAGES_RESOURCEGROUP
from interiorcad.backend.workpiececreationstrategy.creator import WorkpieceCreationStrategy
from interiorcad.backend.workpiece.reader import WorkpieceReader
from interiorcad.backend.surfacedimensioncreator import SurfaceDimensionCreator


class SmallWorkpieceFilter:
    def __init__(self, configuration, minLength, minWidth):
        self.configuration = configuration
        self.minLength = minLength
        self.minWidth = minWidth

    def __getWorkpieceSize(self, workpiece):
        strategy = WorkpieceCreationStrategy.createSizeStrategy(workpiece, self.configuration)
        reader = WorkpieceReader(workpiece)
        sizingAddition = self.configuration.sizingAddition
        creator = SurfaceDimensionCreator(workpieceReader=reader, strategy=strategy, needsMain=True, needsOpposite=False, sizingAddition=sizingAddition)
        return creator.createWorkpieceFilterSize().size

    def filterWorkpiece(self, workpiece):
        size = self.__getWorkpieceSize(workpiece)

        message = None

        if size.x < self.minLength:
            message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 53, "Suppressing workpiece '{workpiece}' because it is not long enough. (Current: {length} Minimal: {minLength})")
        elif size.y < self.minWidth:
            message = getLocalizedString(NCEXPORT_MESSAGES_RESOURCEGROUP, 54, "Suppressing workpiece '{workpiece}' because it is not wide enough. (Current: {width} Minimal: {minWidth})")

        if message:
            logging.warning(message.format(workpiece=workpiece.name, length=size.x, width=size.y, minLength=self.minLength, minWidth=self.minWidth))

        return not bool(message)
