# -*- coding: utf-8 -*-

# Copyright 2011-2022, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import collections

from interiorcad.backend.workpiece import Drilling, DadoRabbet, Miter, Contour, CenterPunch, NCMacro
from interiorcad.backend.workpiece.machininganalyzer import MachiningAnalyzer

Keys = collections.namedtuple("Keys", "vertical horizontal fiveaxis")


CLASSES_TO_KEYS = (
    # DadoRabbet is a special case, see WorkpieceMachiningsSuppressor.getKeyForDadoRabbet
    (Drilling, Keys('verticalDrillings', 'horizontalDrillings', 'fiveAxisDrillings')),
    (Miter, Keys('miters', None, None)),
    (Contour, Keys('verticalContours', 'horizontalContours', None)),
    (CenterPunch, Keys('verticalDrillings', 'horizontalDrillings', 'fiveAxisDrillings')),
    (NCMacro, Keys('verticalNCMacros', 'horizontalNCMacros', 'fiveAxisNCMacros')),
)


class WorkpieceMachiningsFilter:
    def __init__(self, exportMachiningsInfo):
        self.exportMachiningsInfo = exportMachiningsInfo
        self.machiningAnalyzer = MachiningAnalyzer()

    def filterWorkpiece(self, workpiece):
        workpiece.machinings = list(filter(lambda machining3D: self.shouldMachiningBeExported(machining3D, workpiece.finishedSizeShape), workpiece.machinings))
        return True  # This filter does not sort out workpieces. May be EmptyWorkpieceFilter will do it later in the process.

    def shouldMachiningBeExported(self, machining3D, workpieceShape):
        key = self.getKeyForMachining(machining3D, workpieceShape)
        return key is None or self.exportMachiningsInfo[key]

    def getKeyForMachining(self, machining3D, workpieceShape):
        if isinstance(machining3D, DadoRabbet):
            return self.getKeyForDadoRabbet(machining3D, workpieceShape)
        else:
            for class3D, replacement2D in CLASSES_TO_KEYS:
                if isinstance(machining3D, class3D):
                    return self.getKey(machining3D, replacement2D)

    def getKeyForDadoRabbet(self, machining3D, workpieceShape):
        if self.machiningAnalyzer.isVertical(machining3D):
            if self.machiningAnalyzer.isRabbet(machining3D, workpieceShape):
                return 'verticalRabbets'
            else:
                return 'verticalDados'
        elif self.machiningAnalyzer.isHorizontal(machining3D):
            return 'horizontalDados'

    def getKey(self, machining3D, replacement2D):
        if self.machiningAnalyzer.isVertical(machining3D):
            return replacement2D.vertical
        elif self.machiningAnalyzer.isHorizontal(machining3D):
            return replacement2D.horizontal
        else:
            return replacement2D.fiveaxis
