# -*- coding: utf-8 -*-

# Copyright 2011-2014, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

import interiorcad.backend.zvalue.constants as constants


class ZValueConverterConfiguration:
    @staticmethod
    def getOriginFrom(value, defaultPosition):
        return ZValueConverterConfiguration.__getProperty(value, "top", constants.ORIGIN_ON_TOP, constants.ORIGIN_ON_BOTTOM, defaultPosition)

    @staticmethod
    def getDirectionFrom(value, defaultDirection):
        return ZValueConverterConfiguration.__getProperty(value, "up", constants.Z_DIRECTION_UP, constants.Z_DIRECTION_DOWN, defaultDirection)

    @staticmethod
    def __getProperty(value, searchText, positive, negative, default):
        if value:
            return positive if searchText in value.lower() else negative
        else:
            return default


class Tests(unittest.TestCase):
    def testTopUp(self):
        value = "top up"
        self.assertEqual(constants.ORIGIN_ON_TOP, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_UP, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testTopDown(self):
        value = "top down"
        self.assertEqual(constants.ORIGIN_ON_TOP, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_DOWN, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testBottomUp(self):
        value = "bottom up"
        self.assertEqual(constants.ORIGIN_ON_BOTTOM, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_UP, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testBottomDown(self):
        value = "bottom down"
        self.assertEqual(constants.ORIGIN_ON_BOTTOM, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_DOWN, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testUpperCaseTopUp(self):
        value = "TOP UP"
        self.assertEqual(constants.ORIGIN_ON_TOP, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_UP, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testUpperCaseTopDown(self):
        value = "TOP DOWN"
        self.assertEqual(constants.ORIGIN_ON_TOP, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_DOWN, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testUpperCaseBottomUp(self):
        value = "BOTTOM UP"
        self.assertEqual(constants.ORIGIN_ON_BOTTOM, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_UP, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testUpperCaseBottomDown(self):
        value = "BOTTOM DOWN"
        self.assertEqual(constants.ORIGIN_ON_BOTTOM, ZValueConverterConfiguration.getOriginFrom(value, None))
        self.assertEqual(constants.Z_DIRECTION_DOWN, ZValueConverterConfiguration.getDirectionFrom(value, None))

    def testNoneAsValueShouldReturnDefaults(self):
        value = None
        self.assertEqual('position', ZValueConverterConfiguration.getOriginFrom(value, 'position'))
        self.assertEqual('direction', ZValueConverterConfiguration.getDirectionFrom(value, 'direction'))
