# -*- coding: utf-8 -*-

# Copyright 2011-2015, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest
import operator

import interiorcad.backend.zvalue.constants as constants


class ZValueConverter:
    def __init__(self, originReferenceSystem, zAxisDirection):
        self.originReferenceSystem = originReferenceSystem
        self.zAxisDirection = zAxisDirection

    def convertWithThickness(self, thickness, zValue):
        value = zValue
        if self.originReferenceSystem == constants.ORIGIN_ON_BOTTOM:
            value = thickness - zValue

        if operator.xor(self.originReferenceSystem == constants.ORIGIN_ON_TOP, self.zAxisDirection == constants.Z_DIRECTION_DOWN):
            value = -value

        return value

    def convertVariableWithThickness(self, thicknessAsString, zValueAsString):
        value = zValueAsString
        if self.originReferenceSystem == constants.ORIGIN_ON_BOTTOM:
            value = thicknessAsString + '-' + zValueAsString

        if operator.xor(self.originReferenceSystem == constants.ORIGIN_ON_TOP, self.zAxisDirection == constants.Z_DIRECTION_DOWN):
            value = '-(' + value + ')'

        return value

    def convertZValueInAddictionToDirection(self, value):
        if self.zAxisDirection == constants.Z_DIRECTION_DOWN:
            value = -value
        return value

    def createInverted(self):
        return ZValueConverter(1 - self.originReferenceSystem, 1 - self.zAxisDirection)


class TestsOriginOnTop(unittest.TestCase):
    def setUp(self):
        self.THICKNESS = 20

    def testConvertZDirectionDown(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_TOP, constants.Z_DIRECTION_DOWN)
        self.assertEqual(2.5, self.zValueConverter.convertWithThickness(self.THICKNESS, 2.5))

    def testConvertZDirectionUp(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_TOP, constants.Z_DIRECTION_UP)
        self.assertEqual(-2.5, self.zValueConverter.convertWithThickness(self.THICKNESS, 2.5))

    def testConvertVariableZDirectionDown(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_TOP, constants.Z_DIRECTION_DOWN)
        self.assertEqual('VAR', self.zValueConverter.convertVariableWithThickness(str(self.THICKNESS), 'VAR'))

    def testConvertVariableZDirectionUp(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_TOP, constants.Z_DIRECTION_UP)
        self.assertEqual('-(VAR)', self.zValueConverter.convertVariableWithThickness(str(self.THICKNESS), 'VAR'))


class TestsOriginOnBottom(unittest.TestCase):
    def setUp(self):
        self.THICKNESS = 20

    def testConvertZDirectionDown(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_BOTTOM, constants.Z_DIRECTION_DOWN)
        self.assertEqual(-17.5, self.zValueConverter.convertWithThickness(self.THICKNESS, 2.5))

    def testConvertZDirectionUp(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_BOTTOM, constants.Z_DIRECTION_UP)
        self.assertEqual(17.5, self.zValueConverter.convertWithThickness(self.THICKNESS, 2.5))

    def testConvertVariableZDirectionDown(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_BOTTOM, constants.Z_DIRECTION_DOWN)
        self.assertEqual('-(20-VAR)', self.zValueConverter.convertVariableWithThickness(str(self.THICKNESS), 'VAR'))

    def testConvertVariableZDirectionUp(self):
        self.zValueConverter = ZValueConverter(constants.ORIGIN_ON_BOTTOM, constants.Z_DIRECTION_UP)
        self.assertEqual('20-VAR', self.zValueConverter.convertVariableWithThickness(str(self.THICKNESS), 'VAR'))


class InvertTests(unittest.TestCase):
    def testTopDown(self):
        zValueConverter = ZValueConverter(constants.ORIGIN_ON_TOP, constants.Z_DIRECTION_DOWN)
        inverted = zValueConverter.createInverted()
        self.assertEqual(constants.ORIGIN_ON_BOTTOM, inverted.originReferenceSystem)
        self.assertEqual(constants.Z_DIRECTION_UP, inverted.zAxisDirection)

    def testTopUp(self):
        zValueConverter = ZValueConverter(constants.ORIGIN_ON_TOP, constants.Z_DIRECTION_UP)
        inverted = zValueConverter.createInverted()
        self.assertEqual(constants.ORIGIN_ON_BOTTOM, inverted.originReferenceSystem)
        self.assertEqual(constants.Z_DIRECTION_DOWN, inverted.zAxisDirection)

    def testBottomDown(self):
        zValueConverter = ZValueConverter(constants.ORIGIN_ON_BOTTOM, constants.Z_DIRECTION_DOWN)
        inverted = zValueConverter.createInverted()
        self.assertEqual(constants.ORIGIN_ON_TOP, inverted.originReferenceSystem)
        self.assertEqual(constants.Z_DIRECTION_UP, inverted.zAxisDirection)

    def testBottomUp(self):
        zValueConverter = ZValueConverter(constants.ORIGIN_ON_BOTTOM, constants.Z_DIRECTION_UP)
        inverted = zValueConverter.createInverted()
        self.assertEqual(constants.ORIGIN_ON_TOP, inverted.originReferenceSystem)
        self.assertEqual(constants.Z_DIRECTION_DOWN, inverted.zAxisDirection)
