# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase
from interiorcad.backend.filenamecleaner import FilenameCleaner


# noinspection PyUnusedLocal
class BestOptClipboardExport(CuttinglistExportCSVBase):
    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = '\t'

        self.BEST_OPT_ARTICLE = self.getCuttinglistConfiguration().get('best-opt-article', '{CabinetName}')
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')  # | partsandfittings | fittingsonly
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    # header
    def getHeaderLine(self, **keywords):
        return None

    # elements
    def getBestOptArticleVariables(self, **keywords):
        projectInfo = self.getProjectInfo()
        positionInfo = keywords['positionInfo']
        return {
            'CabinetName': positionInfo['CabinetName'],
            'ProjectID': projectInfo['ProjectID'],
            'PositionNumber': positionInfo['PositionNumber'],
        }

    def deleteUnwantedUnderscores(self, element):
        return FilenameCleaner.getSimplifiedMultipleUnderscores(element).strip('_')

    def getBestOptArticle(self, **keywords):
        projectInfo = self.getProjectInfo()
        if not self.isProjectIDValid(**projectInfo) and (self.BEST_OPT_ARTICLE == '{PositionNumber}' or self.BEST_OPT_ARTICLE == '{ProjectID}_{PositionNumber}'):
            self.BEST_OPT_ARTICLE = '{CabinetName}'
        return self.deleteUnwantedUnderscores(self.BEST_OPT_ARTICLE.format_map(self.getBestOptArticleVariables(**keywords)))

    def getElements(self, **keywords):
        entry = keywords['entry']

        return (
            self.asString(data=self.getBestOptArticle(**keywords), **keywords),  # Article (max. 30, but only 15 to 20 visible on prints)
            self.asInt(data=entry.count, **keywords),  # Quantity
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),  # Length
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),  # Width
            self.asCoordinate(data=entry.boardThickness, **keywords),  # Thickness
            self.asString(data=entry.itemID, **keywords),  # Material / ItemID
            self.asString(data=entry.name, **keywords),  # Description
            self.asString(data=entry.edgesGrainDirection.left.supplierID, **keywords),  # Edge Left
            self.asString(data=entry.edgesGrainDirection.right.supplierID, **keywords),  # Edge Right
            self.asString(data=entry.edgesGrainDirection.front.supplierID, **keywords),  # Edge Front
            self.asString(data=entry.edgesGrainDirection.back.supplierID, **keywords),  # Edge Back
        )
