# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class CutterListExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'CutterList'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ';'

        self.EXTENSION = 'csv'
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    def getDecimalSeparator(self, **keywords):
        return '.'

    def getHeaderLine(self, **keywords):
        return None

    def countEdges(self, **keywords):
        return sum(map(lambda edge: bool(edge), keywords['edges']))

    def getElements(self, **keywords):
        entry = keywords['entry']
        return (
            self.asInt(data=entry.count, **keywords),
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),
            self.countEdges(edges=(self.asString(data=entry.edges.front.supplierID, **keywords), self.asString(data=entry.edges.back.supplierID, **keywords)), **keywords),
            self.countEdges(edges=(self.asString(data=entry.edges.left.supplierID, **keywords), self.asString(data=entry.edges.right.supplierID, **keywords)), **keywords),
        )
