# -*- coding: utf-8 -*-

# Copyright 2011-2021, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class EinsAOptExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = '1aOpt'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ';'

        self.EXTENSION = 'csv'
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')
        self.NC_PROGRAM_DISPLAY_NAME_DEFINITION = self.getCuttinglistConfiguration().get('nc-program-display-name-definition', 'namewithextension')

    def getHeaderLine(self, **keywords):
        return None

    def getElements(self, **keywords):
        entry = keywords['entry']
        projectInfo = keywords['projectInfo']
        positionInfo = keywords['positionInfo']

        return (
            # Necessary fields (according to Auftrag field)
            self.asInt(data=entry.count, **keywords),  # Menge (2)
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),  # Länge (5)
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),  # Breite (6)
            self.asString(data=entry.itemID, **keywords),  # Material (4)
            '',  # Kennung (1). Reserved in 1aOpt for proceeding multiple wop-files in one daily order.
            self.asString(data=entry.name, **keywords),  # Bemerkung (3)
            self.asString(data=entry.edgesGrainDirection.front.supplierID, **keywords),  # KV (7)
            '',
            self.asString(data=entry.edgesGrainDirection.back.supplierID, **keywords),  # KH (9)
            '',
            self.asString(data=entry.edgesGrainDirection.left.supplierID, **keywords),  # KL (8)
            '',
            self.asString(data=entry.edgesGrainDirection.right.supplierID, **keywords),  # KR (10)
            '',
            self.asString(key='part_covering1', **keywords),  # BO (11)
            self.asString(key='part_covering2', **keywords),  # BU (12)
            '',  # PBG (14)
            self.asString(data=positionInfo['CabinetName'], **keywords),  # SKZ (18). Could also be variable like ProjectID_PositionNumber_CabinetName?  --mjk
            self.asString(data=positionInfo['PositionNumber'], **keywords),  # POS (20)
            self.asStringSingleLine(key='part_comment', **keywords),  # WText1 (21)
            self.getConstructionGroupNameInclCoveringsAndFittings(**keywords),  # Teiletyp (27)
            self.asString(data=entry.description, **keywords),  # Teiletext (28)

            # Additional user configurable fields WText2 - 6
            self.getNCProgramDisplayName(definition=self.NC_PROGRAM_DISPLAY_NAME_DEFINITION, data=entry.ncProgramPathSizing, **keywords),  # WText2 (22)
            self.getNCProgramDisplayName(definition=self.NC_PROGRAM_DISPLAY_NAME_DEFINITION, data=entry.ncProgramPathMain, **keywords),  # WText3 (23)
            self.getNCProgramDisplayName(definition=self.NC_PROGRAM_DISPLAY_NAME_DEFINITION, data=entry.ncProgramPathOpposite, **keywords),  # WText4 (24)
            self.asString(data=projectInfo['DocumentName'], **keywords),  # WText5 (25)
            '',  # WText6 (26)
        )
