# -*- coding: utf-8 -*-

# Copyright 2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class EnRouteExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'EnRoute'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ','

        self.EXTENSION = 'txt'
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        # We don't use self.CUMULATE_WORKPIECES, because all parts have to be one by one

    def getDecimalSeparator(self, **keywords):
        return '.'

    # header
    def getHeaderLine(self, **keywords):
        return None

    # elements
    def getSimplifiedGrain(self, grain):
        if grain == self.GRAIN_NONE:
            return 1
        else:  # self.GRAIN_LENGTHWISE, self.GRAIN_CROSSWISE:
            return 0

    def getNCProgramNameAndSide(self, **keywords):
        entry = keywords['entry']
        if entry.ncProgramNameSizing:
            return self.asString(data=entry.ncProgramNameSizing or '', **keywords), 'F'
        elif entry.ncProgramNameMain:
            return self.asString(data=entry.ncProgramNameMain or '', **keywords), 'F'
        elif entry.ncProgramNameOpposite:
            return self.asString(data=entry.ncProgramNameOpposite or '', **keywords), 'B'
        else:
            return '', ''

    def getElements(self, **keywords):
        entry = keywords['entry']
        positionInfo = keywords['positionInfo']
        ncProgramName, ncProgramSide = self.getNCProgramNameAndSide(**keywords)

        return (
            ncProgramName,  # File name
            self.asString(data=entry.name, **keywords),  # Part Name
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),  # Width
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),  # Length
            self.asCoordinate(data=entry.boardThickness, **keywords),  # Thickness
            self.asString(data=entry.itemID, **keywords),  # Material Type
            self.getDataAsString(data=positionInfo['CabinetName'], **keywords),  # Unit Number
            self.asInt(data=entry.count, **keywords),  # Quantity
            self.getSimplifiedGrain(entry.grain),  # Allow Rotate.
            0,  # Mirror
            ncProgramSide,  # Front / Back
        )
