# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase
from interiorcad.backend.localization import getLocalizedString, CUTTINGLIST_RESOURCEGROUP


class LacknerExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'Lackner'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = '\t'

        self.EXTENSION = 'dat'
        self.CONFIGURED_SORTING_CRITERIA = self.POSITION_SORTING_CRITERIA

        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsandfittings')  # | partsonly | fittingsonly
        self.CUMULATE_FITTINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-fittings', True)

    def getHeaderLine(self, **keywords):
        return (
            self.getLocalizedHeader(18, 'Position Number'),
            self.getLocalizedHeader(7, 'Unique Name'),
            self.getLocalizedHeader(1, 'Supplier ID'),

            self.getLocalizedHeader(6, 'Count'),
            self.getLocalizedHeader(3, 'Length'),
            self.getLocalizedHeader(4, 'Width'),
            self.getLocalizedHeader(5, 'Thickness'),

            self.getLocalizedHeader(11, 'Edge ID Front 1'),
            self.getLocalizedHeader(12, 'Edge ID Back 2'),
            self.getLocalizedHeader(13, 'Edge ID Left 3'),
            self.getLocalizedHeader(14, 'Edge ID Right 4'),

            self.getLocalizedHeader(25, 'Covering 1'),
            self.getLocalizedHeader(26, 'Covering 2'),

            self.getLocalizedHeader(30, 'Comment'),
        )

    def getElements(self, **keywords):
        entry = keywords['entry']
        positionInfo = keywords['positionInfo']

        return (
            self.asString(data=positionInfo['PositionNumber'], **keywords),
            self.asString(data=entry.name, **keywords),
            self.asString(data=entry.itemID, **keywords),

            self.asInt(data=entry.count, **keywords),
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardThickness, **keywords),

            self.asString(data=entry.edgesGrainDirection.front.supplierID, **keywords),
            self.asString(data=entry.edgesGrainDirection.back.supplierID, **keywords),
            self.asString(data=entry.edgesGrainDirection.left.supplierID, **keywords),
            self.asString(data=entry.edgesGrainDirection.right.supplierID, **keywords),

            self.asString(key='part_covering1', **keywords),
            self.asString(key='part_covering2', **keywords),

            self.asStringSingleLine(key='part_comment', **keywords),
        )

    def getLocalizedHeader(self, index, default):
        return getLocalizedString(CUTTINGLIST_RESOURCEGROUP, index, default)
