# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.backend.datatracker.exporthelper import ExportHelper
from interiorcad.backend.localization import getLocalizedString, CUTTINGLIST_RESOURCEGROUP
from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class MaestroNestingExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'MaestroNesting'

    OUTPUT_ENCODING = 'utf-8-sig'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ';'

        self.EXTENSION = 'csv'
        self.USE_ITEMID = self.getCuttinglistConfiguration().getAsBool('use-itemid', True)

    def getDecimalSeparator(self, **keywords):
        DECIMAL_SEPARATOR = self.getCuttinglistConfiguration().get('decimal-separator', 'system')
        if DECIMAL_SEPARATOR == '.':
            return '.'
        elif DECIMAL_SEPARATOR == ',':
            return ','
        else:  # SystemLocale.getDecimalSeparator()
            return super().getDecimalSeparator(**keywords)

    def getHeaderLine(self, **keywords):
        pass

    # Grain (1 horizontal, 2 vertical. 0 is not documented, but is interpreted as None)
    # Vertical Grain is not used, because current versions of Maestro Nesting do not rotate the workpiece as expected.
    def getSimplifiedGrain(self, grain):
        if grain == self.GRAIN_NONE:
            return 0
        else:  # GRAIN_LENGTHWISE & GRAIN_CROSSWISE
            return 1

    # duplicated with multicenterstudioexport
    def getNCProgramNamesForMainOrOpposite(self, **keywords):
        entry = keywords['entry']
        side = keywords['side']
        path = keywords['path']

        ncProgramNameMain = entry.ncProgramNameMain
        ncProgramNameOpposite = entry.ncProgramNameOpposite

        exportPath = ExportHelper.createExportPathForFirstSelectedCustomPart(self.configuration)
        ncProgramPathMain = entry.ncProgramPathMain
        ncProgramPathOpposite = entry.ncProgramPathOpposite
        if exportPath in ncProgramPathMain or exportPath in ncProgramPathOpposite:
            ncProgramPathMain = ncProgramPathMain.replace(exportPath, '')[1:]
            ncProgramPathOpposite = ncProgramPathOpposite.replace(exportPath, '')[1:]

        if side == 'main' and ncProgramNameMain:
            return ncProgramNameMain if path == 'absolut' else ncProgramPathMain
        elif side == 'main':
            return ncProgramNameOpposite if path == 'absolut' else ncProgramPathOpposite
        elif side == 'opposite' and ncProgramNameMain:
            return ncProgramNameOpposite if path == 'absolut' else ncProgramPathOpposite
        else:
            return ''

    def getElements(self, **keywords):
        entry = keywords['entry']

        return (
            self.asString(data=entry.name, **keywords),  # Workpiece Name
            '',  # Workpiece Type
            self.asString(data=entry.description, **keywords),  # Description
            self.asInt(data=entry.count, **keywords),  # Quantity
            '0',  # ExtraQuantity
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),
            self.asCoordinate(data=entry.thickness, **keywords),  # must be the thickness of the covered part! (instead boardThickness of the raw part)
            self.asString(data=entry.itemID, **keywords) if self.USE_ITEMID else '',
            self.getSimplifiedGrain(grain=entry.grain),
            self.getNCProgramNamesForMainOrOpposite(side='main', path='relative', **keywords),  # File name with extension (relative name of file with extension)
        )
