# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.backend.datatracker.exporthelper import ExportHelper
from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class MultiCenterStudioExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'MultiCenterStudio'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ';'

        self.EXTENSION = 'csv'
        self.EXPORT_LOCATION = self.getCuttinglistConfiguration().get('export-location', 'file')  # | clipboard
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')  # | partsandfittings | fittingsonly
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        # We don't use self.CUMULATE_WORKPIECES, because all parts have to be one by one

    def getHeaderLine(self, **keywords):
        return None

    # duplicated with maestronestingexport
    def getNCProgramNamesForMainOrOpposite(self, **keywords):
        entry = keywords['entry']
        side = keywords['side']
        path = keywords['path']

        ncProgramNameMain = entry.ncProgramNameMain
        ncProgramNameOpposite = entry.ncProgramNameOpposite

        exportPath = ExportHelper.createExportPathForFirstSelectedCustomPart(self.configuration)
        ncProgramPathMain = entry.ncProgramPathMain
        ncProgramPathOpposite = entry.ncProgramPathOpposite
        if exportPath in ncProgramPathMain or exportPath in ncProgramPathOpposite:
            ncProgramPathMain = ncProgramPathMain.replace(exportPath, '')[1:]
            ncProgramPathOpposite = ncProgramPathOpposite.replace(exportPath, '')[1:]

        if side == 'main' and ncProgramNameMain:
            return ncProgramNameMain if path == 'absolut' else ncProgramPathMain
        elif side == 'main':
            return ncProgramNameOpposite if path == 'absolut' else ncProgramPathOpposite
        elif side == 'opposite' and ncProgramNameMain:
            return ncProgramNameOpposite if path == 'absolut' else ncProgramPathOpposite
        else:
            return ''

    def getRotationAngle(self, **keywords):
        entry = keywords['entry']
        grain = entry.grain

        if grain == self.GRAIN_LENGTHWISE or grain == self.GRAIN_CROSSWISE:
            return 180
        elif grain == self.GRAIN_NONE and entry.workpiece.isRectangular():
            return 90
        elif grain == self.GRAIN_NONE and entry.workpiece.isPolygonal():
            return 5
        else:
            return 0

    def getElements(self, **keywords):
        entry = keywords['entry']
        projectInfo = keywords['projectInfo']
        positionInfo = keywords['positionInfo']

        return (
            # Base columns
            self.getNCProgramNamesForMainOrOpposite(side='main', path='relative', **keywords),
            self.asInt(data=entry.count, **keywords),
            self.getRotationAngle(**keywords),
            'FALSE',  # Spiegeln erlaubt
            self.asString(data=entry.itemID, **keywords),
            'FALSE',  # Füllstück

            # Free columns
            self.asStringSingleLine(key='part_comment', **keywords),  # Etiketteninfos

            # Kanteninfos
            self.asString(key='part_edge1', **keywords),  # Vorne
            self.asCoordinate(key='part_edge1thickness', **keywords),
            self.asString(key='part_edge2', **keywords),  # Hinten
            self.asCoordinate(key='part_edge2thickness', **keywords),
            self.asString(key='part_edge3', **keywords),  # Links
            self.asCoordinate(key='part_edge3thickness', **keywords),
            self.asString(key='part_edge4', **keywords),  # Rechts
            self.asCoordinate(key='part_edge4thickness', **keywords),

            self.asString(data=entry.name, **keywords),
            self.asString(data=entry.description, **keywords),

            self.asString(data=projectInfo['ProjectCommission'], **keywords),  # Kunde
            self.asString(data=projectInfo['ProjectID'], **keywords),  # Projektnummer
            self.asString(data=projectInfo['ProjectConstruction'], **keywords),  # Bauvorhaben
            self.asString(data=positionInfo['PositionNumber'], **keywords),  # Positionsnummer
            self.asString(data=positionInfo['PositionDescription'], **keywords),  # Positionsbezeichnung
            self.asString(data=positionInfo['CabinetName'], **keywords),  # Korpusmöbelname

            self.asString(key='part_covering1', **keywords),
            self.asString(key='part_covering2', **keywords),

            self.getNCProgramNamesForMainOrOpposite(side='opposite', path='absolut', **keywords),
        )
