# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import os.path

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase
from interiorcad.backend.localization import getLocalizedString, CUTTINGLIST_OUTPUT_FILE_NAMES_RESOURCEGROUP


class OPALExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = os.path.splitext(getLocalizedString(CUTTINGLIST_OUTPUT_FILE_NAMES_RESOURCEGROUP, 2, "OPAL.csv"))[0]

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ';'

        self.EXTENSION = 'csv'

        # TODO IT-216: SCOPE_OF_EXPORT, CUMULATE_COVERINGS ergänzen
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    def getHeaderLine(self, **keywords):
        return (
            'AUFKB',
            'AUFPOS',
            'PLAKB',
            'TEILBEZ',
            'STÜCK',
            'ZUSLÄNGE',
            'ZUSBREITE',
            'DREHBAR',
            'BELAGIKB',
            'BELAGAKB',
            'KANTEVKB',
            'KANTEVDICKE',
            'KANTEHKB',
            'KANTEHDICKE',
            'KANTELKB',
            'KANTELDICKE',
            'KANTERKB',
            'KANTERDICKE',
            'ZUSBEZ',
        )

    def getSimplifiedGrain(self, grain):
        # If the part can be rotated
        # TODO: translated? Or Y N? -- NG (IT-210)
        if grain == self.GRAIN_NONE:
            return 'ja'
        else:  # self.GRAIN_LENGTHWISE, self.GRAIN_CROSSWISE:
            return 'nein'

    def getElements(self, **keywords):
        entry = keywords['entry']
        projectInfo = keywords['projectInfo']
        positionInfo = keywords['positionInfo']

        return (
            self.asString(data=projectInfo['ProjectID'], **keywords),
            self.asString(data=positionInfo['PositionNumber'], **keywords),
            self.asString(data=entry.itemID, **keywords),
            self.asString(data=entry.name, **keywords),
            self.asInt(data=entry.count, **keywords),
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),
            self.asString(data=self.getSimplifiedGrain(entry.grain), **keywords),
            self.asString(key='part_covering1', **keywords),
            self.asString(key='part_covering2', **keywords),
            self.asString(data=entry.edgesGrainDirection.front.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.front.thickness, **keywords),
            self.asString(data=entry.edgesGrainDirection.back.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.back.thickness, **keywords),
            self.asString(data=entry.edgesGrainDirection.left.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.left.thickness, **keywords),
            self.asString(data=entry.edgesGrainDirection.right.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.right.thickness, **keywords),
            self.asStringSingleLine(key='part_comment', **keywords),
        )

    def writeListHeader(self, **keywords):
        super().writeListHeader(**keywords)
        self.csvWriter.writerow('')  # empty row between Header and Body
