# -*- coding: utf-8 -*-

# Copyright 2011-2020, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class OPCUTExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'OPCUT'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = ';'

        self.EXTENSION = 'csv'
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    def getHeaderLine(self, **keywords):
        return None

    def getElements(self, **keywords):
        entry = keywords['entry']
        return (
            self.asInt(data=entry.count, **keywords),
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),
            self.asString(data=entry.itemID, **keywords),
            self.asStringSingleLine(key='part_comment', **keywords),
            self.asString(data=entry.name, **keywords),
            self.asString(data=entry.edgesGrainDirection.front.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.front.thickness, **keywords),
            self.asString(data=entry.edgesGrainDirection.back.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.back.thickness, **keywords),
            self.asString(data=entry.edgesGrainDirection.left.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.left.thickness, **keywords),
            self.asString(data=entry.edgesGrainDirection.right.supplierID, **keywords),
            self.asCoordinate(data=entry.edgesGrainDirection.right.thickness, **keywords),
            self.asString(key='part_covering1', **keywords),
            self.asString(key='part_covering2', **keywords),
        )
