# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class ProOptimizeExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'ProOptimize'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = '\t'
        self.counter = 0

        self.EXTENSION = 'txt'
        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    def getCoordinatePrecision(self, **keywords):
        # set hard to 0, because ProOptimize can't handle floating numbers
        return 0

    # header
    def getHeaderLine(self, **keywords):
        # Prefix:"Stück\tBez\tMaterial\tLänge\tBreite\tStärke\tAuftrag\tPos\tTeilenr\r\n"
        return (
            'Anzahl',
            'Bezeichnung',
            'Material',
            'Länge',
            'Breite',
            'Stärke',
            'ProjektNr',
            'Position',
            'LfdNr',
        )

    # body
    def getElements(self, **keywords):
        self.counter += 1
        entry = keywords['entry']
        projectInfo = keywords['projectInfo']
        positionInfo = keywords['positionInfo']

        return (
            self.asInt(data=entry.count, **keywords),  # STIAnzahl
            self.asString(data=entry.name, **keywords),  # STIBaugruppenName
            self.asString(data=entry.itemID, **keywords),  # STIArtikelNr
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),  # STILaenge
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),  # STIBreite
            self.asCoordinate(data=entry.boardThickness, **keywords),  # STIHoehe
            self.asString(data=projectInfo['ProjectID'], **keywords),  # STIAuftragNummer
            self.asString(data=positionInfo['PositionNumber'], **keywords),  # STIPositionNummer
            self.asInt(data=self.counter, **keywords),  # STITeileNummer
        )
