# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase


class WoodWorksExport(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'WoodWorks'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = '\t'

        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    def getHeaderLine(self, **keywords):
        return None

    def getSimplifiedGrain(self, grain):
        # N= part must not be rotated, Y= part can be rotated
        if grain == self.GRAIN_NONE:
            return 'Y'
        else:  # self.GRAIN_LENGTHWISE, self.GRAIN_CROSSWISE:
            return 'N'

    def getElements(self, **keywords):
        entry = keywords['entry']
        # projectInfo = keywords['projectInfo']
        positionInfo = entry.positionInfo

        return (
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),
            self.asInt(data=entry.count, **keywords),
            self.getSimplifiedGrain(entry.grain),  # rotatable Y/N
            'Y' if self.asString(data=entry.edgesGrainDirection.back.supplierID, **keywords) else 'N',
            'Y' if self.asString(data=entry.edgesGrainDirection.front.supplierID, **keywords) else 'N',
            'Y' if self.asString(data=entry.edgesGrainDirection.left.supplierID, **keywords) else 'N',
            'Y' if self.asString(data=entry.edgesGrainDirection.right.supplierID, **keywords) else 'N',
            self.asString(data=entry.name, **keywords),
            self.getDataAsString(data=positionInfo['CabinetName'], **keywords),
            # self.asString(data=entry.itemID, **keywords),   # not necessary
        )
