# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.cuttinglistexport.csvbase import CuttinglistExportCSVBase
from interiorcad.backend.utilities.stringconcatenation import joinIfNotNone


class Zuschnitt24Export(CuttinglistExportCSVBase):
    EXPORT_FORMAT = 'Zuschnitt24'

    def __init__(self, **keywords):
        super().__init__(**keywords)
        self.csvdelimiter = '\t'

        self.SCOPE_OF_EXPORT = self.getCuttinglistConfiguration().get('scope-of-export', 'partsonly')
        self.CUMULATE_COVERINGS = self.getCuttinglistConfiguration().getAsBool('cumulate-coverings', False)
        self.CUMULATE_WORKPIECES = self.getCuttinglistConfiguration().get('cumulate-workpieces', 'none')

    # header
    def getHeaderLine(self, **keywords):
        pass

    # body
    def getElements(self, **keywords):
        entry = keywords['entry']
        return (
            self.asString(data=entry.itemID, **keywords),  # Material
            self.asCoordinate(data=entry.boardLengthGrainDirection, **keywords),  # Länge
            self.asCoordinate(data=entry.boardWidthGrainDirection, **keywords),  # Breite
            self.asInt(data=entry.count, **keywords),  # Anzahl
            self.asString(data=entry.name, **keywords),  # Bemerkung für Teilebezeichnung
            self.createIdentifierForElement(**keywords),  # Kennung für zusätzliche Anmerkungen
        )

    def createIdentifierForElement(self, **keywords):
        positionInfo = keywords['positionInfo']
        positionNumber = self.asString(data=positionInfo['PositionNumber'], **keywords)
        positionDescription = self.asString(data=positionInfo['PositionDescription'], **keywords)
        cabinetName = self.asString(data=positionInfo['CabinetName'], **keywords)
        comment = self.asStringSingleLine(key='part_comment', **keywords)
        return joinIfNotNone(' / ',
            'Pos. {pos}'.format(pos=positionNumber if positionNumber else None),
            positionDescription if positionDescription else None,
            cabinetName if cabinetName else None,
            comment if comment else None,
        )
