# -*- coding: utf-8 -*-

# Copyright 2016-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest
import math

from interiorcad.interface.geometry.point import Point


def __getCentersOfArcThroughTwoPoints(point1, point2, radius):
    # http://mathforum.org/library/drmath/view/53027.html  # Meanwhile, the reference is obsolete.
    x1, y1 = point1.x, point1.y
    x2, y2 = point2.x, point2.y
    r = radius

    x3 = (x1 + x2) / 2
    y3 = (y1 + y2) / 2

    q = math.hypot(x2 - x1, y2 - y1)

    # HACK: the datatracker could provide a difference in the 15th decimal place for the radius, which leads to a negative sqrt() (ID-355)
    try:
        modFactor = math.sqrt(r**2 - (q / 2) ** 2)
    except ValueError:
        modFactor = 0

    modX = modFactor * (y1 - y2) / q
    modY = modFactor * (x2 - x1) / q

    center1 = Point(x3 + modX, y3 + modY)
    center2 = Point(x3 - modX, y3 - modY)

    return center1, center2


def getCenterOfThreePointsOnArc(pointStart, point, pointEnd, radius):
    center1, center2 = __getCentersOfArcThroughTwoPoints(pointStart, pointEnd, radius)
    center3, center4 = __getCentersOfArcThroughTwoPoints(pointStart, point, radius)

    if center1 == center3:
        return center1
    elif center1 == center4:
        return center1
    elif center2 == center3:
        return center2
    elif center2 == center4:
        return center2
    else:
        assert False, "No center point found!"


class Tests(unittest.TestCase):
    def testCenterAtZeroZero(self):
        point1 = Point(-100, 0)
        point2 = Point(0, 100)
        point3 = Point(100, 0)
        radius = 100

        self.assertEqual(Point(0, 0), getCenterOfThreePointsOnArc(point1, point2, point3, radius))

    def testSomewhereElse(self):
        point1 = Point(100, 300)
        point2 = Point(200, 200)
        point3 = Point(0, 200)
        radius = 100

        self.assertEqual(Point(100, 200), getCenterOfThreePointsOnArc(point1, point2, point3, radius))
