# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


import unittest

from interiorcad.interface.geometry import isNearlyEqual
from interiorcad.interface.geometry.vertex import Vertex


class RadiusVertex(Vertex):
    def __init__(self, position=None, visible=True, radius=0.0):
        super().__init__(position, visible)
        self.radius = radius

    def __eq__(self, other):
        return isinstance(other, self.__class__) and isNearlyEqual(self.radius, other.radius) and super().__eq__(other)

    def isCornerVertex(self):
        return False

    def isRadiusVertex(self):
        return True

    @property
    def type(self):
        return Vertex.RADIUS_VERTEX

    def __str__(self):
        return ' '.join((
            'RadiusVertex:',
            super().__str__() + ';',
            'radius({:.{}f})'.format(self.radius, 2),
        ))


class RadiusVertexTest(unittest.TestCase):
    def setUp(self):
        self.rv = RadiusVertex()

    def testRadiusVertexIsInstanceOfVertex(self):
        self.assertIsInstance(self.rv, Vertex)
        self.assertTrue(self.rv.position)
        self.assertTrue(self.rv.visible)

    def testDefaultVertexHasRadiusZero(self):
        self.assertEqual(0, self.rv.radius)


class RadiusVertexCreationTest(unittest.TestCase):
    def testCanCreateVertex(self):
        self.assertTrue(RadiusVertex())

    def testCanSetPositionInConstructor(self):
        rv = RadiusVertex('position')
        self.assertEqual('position', rv.position)

    def testCanSetRadiusInConstructor(self):
        rv = RadiusVertex(radius='radius')
        self.assertEqual('radius', rv.radius)


class RadiusVertexBoolOperatorTest(unittest.TestCase):
    def setUp(self):
        self.rv = RadiusVertex('1')

    def testSameVertexAreEqual(self):
        self.assertEqual(self.rv, self.rv)

    def testDefaultVerticesAreEqual(self):
        self.assertEqual(RadiusVertex(), RadiusVertex())

    def testSameVerticesAreEqual(self):
        self.assertEqual(RadiusVertex('1'), self.rv)

    def testDifferentVerticesAreNotEqual(self):
        self.assertNotEqual(RadiusVertex('2'), self.rv)

    def testVertexAndRadiusVertexAreNotEqual(self):
        self.assertNotEqual(self.rv, Vertex('1'))
