# -*- coding: utf-8 -*-

# Copyright 2011-2024, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import interiorcad.backend.exportdatasafe
from interiorcad.interface.keyvalueconfiguration import KeyValueConfiguration
from interiorcad.interface.machineconfiguration.mockmachineconfiguration import MOCK_MACHINE_CONFIGURATION_WITH_TOOL_DATABASE_XML
from interiorcad.interface.machineconfiguration.tooldatabase import ToolDatabase
from interiorcad.interface.machineconfiguration.tooldatabasereader import ToolDatabaseReader


NC_MACHINE_CONFIGURATIONS = "machine-configuration"
NC_KEY_VALUE_PAIR = "keyvaluepair"


class MachineConfiguration(KeyValueConfiguration):
    def getMockDefaultXMLCode(self):
        return MOCK_MACHINE_CONFIGURATION_WITH_TOOL_DATABASE_XML

    def readFullXMLFile(self):
        self.configurations = dict((item['key'], item['value']) for item in self.getAllAttributesOfAllChildrenWithTag(NC_MACHINE_CONFIGURATIONS, NC_KEY_VALUE_PAIR))
        self.__readTools()

    def readActiveTools(self, toolDatabaseElement):
        reader = ToolDatabaseReader(self.toolDatabase)
        reader.process(toolDatabaseElement)

    def __readTools(self):
        toolDatabaseElement = self.root.find('tool-database')
        self.toolDatabase = ToolDatabase()
        if toolDatabaseElement is not None:
            self.readActiveTools(toolDatabaseElement)

    def getMachineConfigurationFileName(self):
        if interiorcad.backend.exportdatasafe.SCRIPTS_AND_CONFIGURATIONS:
            return interiorcad.backend.exportdatasafe.SCRIPTS_AND_CONFIGURATIONS[0][1]

    def getFileName(self):
        return  self.getMachineConfigurationFileName()
