# -*- coding: utf-8 -*-

# Copyright 2016, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest


class ToolAxis:
    NONE, PLUS, MINUS, BOTH = range(4)

    def __init__(self):
        self.x = ToolAxis.NONE
        self.y = ToolAxis.NONE
        self.cRotating = False

    def __eq__(self, rhs):
        return all((
            self.x == rhs.x,
            self.y == rhs.y,
            self.cRotating == rhs.cRotating,
        ))

    def __repr__(self):
        return 'ToolAxis(x={x}, y={y}, cRotating={cRotating})'.format(x=self.x, y=self.y, cRotating=self.cRotating)

    def isXAllowed(self):
        return self.x != ToolAxis.NONE

    def isYAllowed(self):
        return self.y != ToolAxis.NONE

    def isXMinusAllowed(self):
        return self.x == ToolAxis.MINUS or self.x == ToolAxis.BOTH

    def isYMinusAllowed(self):
        return self.y == ToolAxis.MINUS or self.y == ToolAxis.BOTH

    def isXPlusAllowed(self):
        return self.x == ToolAxis.PLUS or self.x == ToolAxis.BOTH

    def isYPlusAllowed(self):
        return self.y == ToolAxis.PLUS or self.y == ToolAxis.BOTH


class Tests(unittest.TestCase):
    def setUp(self):
        self.toolAxis = ToolAxis()

    def testXNone(self):
        self.toolAxis.x = ToolAxis.NONE
        self.assertFalse(self.toolAxis.isXAllowed())
        self.assertFalse(self.toolAxis.isXMinusAllowed())
        self.assertFalse(self.toolAxis.isXPlusAllowed())

    def testYNone(self):
        self.toolAxis.y = ToolAxis.NONE
        self.assertFalse(self.toolAxis.isYAllowed())
        self.assertFalse(self.toolAxis.isYMinusAllowed())
        self.assertFalse(self.toolAxis.isYPlusAllowed())

    def testXBoth(self):
        self.toolAxis.x = ToolAxis.BOTH
        self.assertTrue(self.toolAxis.isXAllowed())
        self.assertTrue(self.toolAxis.isXMinusAllowed())
        self.assertTrue(self.toolAxis.isXPlusAllowed())

    def testYBoth(self):
        self.toolAxis.y = ToolAxis.BOTH
        self.assertTrue(self.toolAxis.isYAllowed())
        self.assertTrue(self.toolAxis.isYMinusAllowed())
        self.assertTrue(self.toolAxis.isYPlusAllowed())

    def testMinus(self):
        self.toolAxis.x = ToolAxis.MINUS
        self.assertTrue(self.toolAxis.isXAllowed())
        self.assertTrue(self.toolAxis.isXMinusAllowed())
        self.assertFalse(self.toolAxis.isXPlusAllowed())

    def testYMinus(self):
        self.toolAxis.y = ToolAxis.MINUS
        self.assertTrue(self.toolAxis.isYAllowed())
        self.assertTrue(self.toolAxis.isYMinusAllowed())
        self.assertFalse(self.toolAxis.isYPlusAllowed())

    def testXPlus(self):
        self.toolAxis.x = ToolAxis.PLUS
        self.assertTrue(self.toolAxis.isXAllowed())
        self.assertFalse(self.toolAxis.isXMinusAllowed())
        self.assertTrue(self.toolAxis.isXPlusAllowed())

    def testYPlus(self):
        self.toolAxis.y = ToolAxis.PLUS
        self.assertTrue(self.toolAxis.isYAllowed())
        self.assertFalse(self.toolAxis.isYMinusAllowed())
        self.assertTrue(self.toolAxis.isYPlusAllowed())
