# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.machiningsexporter.horizontaldrillingsexporter import HorizontalMachiningsExporter_SeparateCallForMachiningsOnBounds
from interiorcad.interface.surface.origins import SURFACE_ORIGIN_FRONT_LEFT


# We need this listener class to be able to reuse the current system of determining which drilling is a 'rotated' drilling and which is a non-rotated drilling.

class HorizontalMachiningsListener:
    def __init__(self):
        self.rotatedHorizontalMachinings = []
        self.horizontalMachiningsOnBounds = []

    def createRotated(self, **keywords):
        self.rotatedHorizontalMachinings.append(keywords['machining'])
        return ''

    def createNonRotated(self, **keywords):
        self.horizontalMachiningsOnBounds.append(keywords['machining'])
        return ''

    def createFromRight(self, **keywords):
        return self.createNonRotated(**keywords)

    def createFromLeft(self, **keywords):
        return self.createNonRotated(**keywords)

    def createFromFront(self, **keywords):
        return self.createNonRotated(**keywords)

    def createFromBack(self, **keywords):
        return self.createNonRotated(**keywords)


class RotatedHorizontalDrillingsFinder:
    class DummyExport:
        SURFACE_ORIGIN = SURFACE_ORIGIN_FRONT_LEFT

        def getHorizontalDrillingZValue(self, **keywords):
            return -0.0

    def get(self, surface):
        return self.__createHorizontalMachinings(surface, surface.horizontalDrillingsAndCenterPunches)

    def __createHorizontalMachinings(self, surface, machinings):
        splitter = HorizontalMachiningsListener()
        exporter = HorizontalMachiningsExporter_SeparateCallForMachiningsOnBounds(export=self.DummyExport())
        exporter.machiningCreator = splitter
        exporter.machinings = machinings
        exporter.createHorizontalMachinings(surface=surface)
        return splitter.rotatedHorizontalMachinings
