# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import math

from interiorcad.interface.geometry.point import Point


def createArcApproach(left, **keywords):
    startVertex = keywords['startVertex']
    endVertex = keywords['segmentList'][0].getEndVertex()
    securityDistance = keywords['securityDistance']
    firstSegmentVector = (endVertex.position - startVertex.position)
    firstSegmentVector.normalize()

    if left:
        perpendicularVector = - firstSegmentVector.perp()
        isClockwise = False
    else:
        perpendicularVector = firstSegmentVector.perp()
        isClockwise = True

    approachDelta = (perpendicularVector - firstSegmentVector) * securityDistance
    tangentialAngle = math.degrees(math.atan2(firstSegmentVector.y, firstSegmentVector.x))

    approachPoint = Point(startVertex.position.x + approachDelta.x, startVertex.position.y + approachDelta.y)
    centerPoint = startVertex.position + perpendicularVector * securityDistance

    return isClockwise, approachDelta, approachPoint, centerPoint, tangentialAngle


def createArcDeparture(left, **keywords):
    startVertex = keywords['segmentList'][-1].getStartVertex()
    endVertex = keywords['segmentList'][-1].getEndVertex()
    securityDistance = keywords['securityDistance']
    firstSegmentVector = (endVertex.position - startVertex.position)
    firstSegmentVector.normalize()

    if left:
        perpendicularVector = - firstSegmentVector.perp()
        isClockwise = False
    else:
        perpendicularVector = firstSegmentVector.perp()
        isClockwise = True

    departureDelta = (perpendicularVector + firstSegmentVector) * securityDistance

    departurePoint = Point(endVertex.position.x + departureDelta.x, endVertex.position.y + departureDelta.y)
    centerPoint = endVertex.position + perpendicularVector * securityDistance

    return isClockwise, departureDelta, departurePoint, centerPoint


def createLinearApproach(ncexport, **keywords):
    startVertex = keywords['startVertex']
    endVertex = keywords['segmentList'][0].getEndVertex()
    firstSegmentVector = (endVertex.position - startVertex.position)
    firstSegmentVector.normalize()
    approachDelta = - firstSegmentVector * keywords['securityDistance']

    approachPoint = Point(startVertex.position.x + approachDelta.x, startVertex.position.y + approachDelta.y)

    return approachDelta, approachPoint


def createLinearDeparture(ncexport, **keywords):
    startVertex = keywords['segmentList'][-1].getStartVertex()
    endVertex = keywords['segmentList'][-1].getEndVertex()
    firstSegmentVector = (endVertex.position - startVertex.position)
    firstSegmentVector.normalize()
    departureDelta = firstSegmentVector * keywords['securityDistance']

    departurePoint = Point(endVertex.position.x + departureDelta.x, endVertex.position.y + departureDelta.y)

    return departureDelta, departurePoint
