# -*- coding: utf-8 -*-

# Copyright 2011-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.ncexport.baseexporter import BaseExporter


class GannoMATExporter(BaseExporter):
    def exportWorkpieceSurfaces(self, workpiece, surfaceCreator, programNamesHandler):
        # For GannoMAT we export systematically as a both-sided program, except if there is only an opposite side. (IC-14764)

        surfaces = surfaceCreator.createSurfaces()

        self.firstSide = True
        self.hasMainSide = surfaces.hasMain()
        self.hasOppositeSide = surfaces.hasOpposite()

        if surfaceCreator.needsOpposite() and not surfaceCreator.needsMain() and not surfaceCreator.needsSizing():
            surface = surfaceCreator.createOpposite()
            ncProgramNameWriteBackFunc = programNamesHandler.setNCProgramNameOpposite
            filePostfix = self.ncexport.FILE_NAME_POSTFIX_OPPOSITE
        else:
            surface = surfaceCreator.createBothSided()
            ncProgramNameWriteBackFunc = programNamesHandler.setNCProgramNameMain
            filePostfix = self.ncexport.FILE_NAME_POSTFIX_BOTH_SIDED

        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide

        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=ncProgramNameWriteBackFunc, filePostfix=filePostfix)

        self.firstSide = False
