# -*- coding: utf-8 -*-

# Copyright 2011-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.ncexport.baseexporter import BaseExporter


class GeneralExporter(BaseExporter):
    def exportWorkpieceSurfaces(self, workpiece, surfaceCreator, programNamesHandler):
        surfaces = surfaceCreator.createSurfaces()

        self.firstSide = True
        self.hasMainSide = surfaces.hasMain()
        self.hasOppositeSide = surfaces.hasOpposite()

        if surfaces.hasSizing():
            self.createSizingSide(surfaces.sizing, programNamesHandler)
            self.firstSide = False

        if surfaces.hasMain():
            self.createMainSide(surfaces.main, programNamesHandler)
            self.firstSide = False

        if surfaces.hasOpposite():
            self.createOppositeSide(surfaces.opposite, programNamesHandler)
            self.firstSide = False

    def createSizingSide(self, surface, programNamesHandler, **keywords):
        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide
        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=programNamesHandler.setNCProgramNameSizing, filePostfix=self.ncexport.FILE_NAME_POSTFIX_SIZING, **keywords)

    def createMainSide(self, surface, programNamesHandler, **keywords):
        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide
        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=programNamesHandler.setNCProgramNameMain, filePostfix=self.ncexport.FILE_NAME_POSTFIX_MAIN, **keywords)

    def createOppositeSide(self, surface, programNamesHandler, **keywords):
        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide
        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=programNamesHandler.setNCProgramNameOpposite, filePostfix=self.ncexport.FILE_NAME_POSTFIX_OPPOSITE, **keywords)
