# -*- coding: utf-8 -*-

# Copyright 2011-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

from interiorcad.interface.ncexport.baseexporter import BaseExporter
from interiorcad.interface.surface import SURFACE_SIDE_TYPE_BOTH_SIDED


class OneProgramExporter(BaseExporter):
    def exportWorkpieceSurfaces(self, workpiece, surfaceCreator, programNamesHandler):
        surfaces = surfaceCreator.createSurfaces()

        self.firstSide = True
        self.hasMainSide = surfaces.hasMain()
        self.hasOppositeSide = surfaces.hasOpposite()

        # Separate sizing remains separate
        if surfaces.hasSizing():
            self.createSizingSide(surfaces.sizing, programNamesHandler)
            self.firstSide = False

        if surfaces.hasMain() and surfaces.hasOpposite():
            self.createMainAndOppositeSidesTogether(surfaces, programNamesHandler)
            self.firstSide = False
        elif surfaces.hasMain():
            self.createMainSide(surfaces.main, programNamesHandler)
            self.firstSide = False
        elif surfaces.hasOpposite():
            self.createOppositeSide(surfaces.opposite, programNamesHandler)
            self.firstSide = False

    def createSizingSide(self, surface, programNamesHandler):
        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide
        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=programNamesHandler.setNCProgramNameSizing, filePostfix=self.ncexport.FILE_NAME_POSTFIX_SIZING)

    def createMainSide(self, surface, programNamesHandler):
        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide
        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=programNamesHandler.setNCProgramNameMain, filePostfix=self.ncexport.FILE_NAME_POSTFIX_MAIN)

    def createOppositeSide(self, surface, programNamesHandler):
        surface.isFirstSide = self.firstSide
        surface.hasMainSide = self.hasMainSide
        surface.hasOppositeSide = self.hasOppositeSide
        self.ncexport.createSide(surface=surface, ncProgramNameWriteBackFunc=programNamesHandler.setNCProgramNameOpposite, filePostfix=self.ncexport.FILE_NAME_POSTFIX_OPPOSITE)

    def createMainAndOppositeSidesTogether(self, surfaces, programNamesHandler):
        keywords = {
            'ncProgramNameWriteBackFunc': programNamesHandler.setNCProgramNameMain,
            'filePostfix': self.ncexport.FILE_NAME_POSTFIX_BOTH_SIDED,
        }

        # TODO ISP-24: Was wollen wir hier wirklich?  --mjk
        # "surfaces.main" to be able to find workpiece data
        mainSurface = surfaces.main
        mainSurface.isFirstSide = self.firstSide

        oppositeSurface = surfaces.opposite
        oppositeSurface.isFirstSide = False

        mainSurface.sideType = oppositeSurface.sideType = SURFACE_SIDE_TYPE_BOTH_SIDED  # We need to explicitely set it, as it is still SURFACE_SIDE_TYPE_MAIN | OPPOSITE
        mainSurface.hasMainSide = oppositeSurface.hasMainSide = self.hasMainSide
        mainSurface.hasOppositeSide = oppositeSurface.hasOppositeSide = self.hasOppositeSide

        fileContent = ''.join(self.ncexport.createMainAndOppositeSidesTogether(mainSurface=mainSurface, oppositeSurface=oppositeSurface, **keywords))
        self.ncexport.writeFileContent(surface=mainSurface, fileContent=fileContent, **keywords)
