# -*- coding: utf-8 -*-

# Copyright 2011-2018, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH


import unittest

from interiorcad.interface.geometry.vector import Vector
from interiorcad.interface.geometry import isNearlyEqual, EPSILON


# TODO InnoWeek 2018-06: gibt es eine andere Methode, die weniger nach Holzhammerart ist? -- NG
from interiorcad.interface.surface.origins import SURFACE_ORIGIN_FRONT_LEFT, SURFACE_ORIGIN_BACK_LEFT, SURFACE_ORIGIN_FRONT_RIGHT


class MachiningDirection:
    def __rawIsFromLeft(self, direction):
        return direction == Vector(-1, 0, 0)

    def __rawIsFromRight(self, direction):
        return direction == Vector(1, 0, 0)

    def __rawIsFromFront(self, direction):
        return direction == Vector(0, -1, 0)

    def __rawIsFromBack(self, direction):
        return direction == Vector(0, 1, 0)

    def isFromLeft(self, direction, origin=SURFACE_ORIGIN_FRONT_LEFT):
        if origin == SURFACE_ORIGIN_FRONT_LEFT or origin == SURFACE_ORIGIN_BACK_LEFT:
            return self.__rawIsFromLeft(direction)
        else:
            return self.__rawIsFromRight(direction)

    def isFromRight(self, direction, origin=SURFACE_ORIGIN_FRONT_LEFT):
        if origin == SURFACE_ORIGIN_FRONT_LEFT or origin == SURFACE_ORIGIN_BACK_LEFT:
            return self.__rawIsFromRight(direction)
        else:
            return self.__rawIsFromLeft(direction)

    def isFromFront(self, direction, origin=SURFACE_ORIGIN_FRONT_LEFT):
        if origin == SURFACE_ORIGIN_FRONT_LEFT or origin == SURFACE_ORIGIN_FRONT_RIGHT:
            return self.__rawIsFromFront(direction)
        else:
            return self.__rawIsFromBack(direction)

    def isFromBack(self, direction, origin=SURFACE_ORIGIN_FRONT_LEFT):
        if origin == SURFACE_ORIGIN_FRONT_LEFT or origin == SURFACE_ORIGIN_FRONT_RIGHT:
            return self.__rawIsFromBack(direction)
        else:
            return self.__rawIsFromFront(direction)

    def isVerticalFromTop(self, direction):
        return isNearlyEqual(direction.z, 1)

    def isVerticalFromBottom(self, direction):
        return isNearlyEqual(direction.z, -1)


class MachiningDirectionTest(unittest.TestCase):
    def testIsFromLeft(self):
        self.assertTrue(MachiningDirection().isFromLeft(Vector(-1, 0, 0)))

    def testIsFromRight(self):
        self.assertTrue(MachiningDirection().isFromRight(Vector(1, 0, 0)))

    def testIsFromFront(self):
        self.assertTrue(MachiningDirection().isFromFront(Vector(0, -1, 0)))

    def testIsFromBack(self):
        self.assertTrue(MachiningDirection().isFromBack(Vector(0, 1, 0)))


class VerticalTests(unittest.TestCase):
    def testFromTop(self):
        direction = Vector(0, 0, 1)
        self.assertTrue(MachiningDirection().isVerticalFromTop(direction))
        self.assertFalse(MachiningDirection().isVerticalFromBottom(direction))

    def testFromTopEpsilon(self):
        direction = Vector(0, 0, 1 - EPSILON / 2)
        self.assertTrue(MachiningDirection().isVerticalFromTop(direction))
        self.assertFalse(MachiningDirection().isVerticalFromBottom(direction))

    def testFromBottom(self):
        direction = Vector(0, 0, -1)
        self.assertFalse(MachiningDirection().isVerticalFromTop(direction))
        self.assertTrue(MachiningDirection().isVerticalFromBottom(direction))

    def testIsYPlusEpsilon(self):
        direction = Vector(0, 0, -1 + EPSILON / 2)
        self.assertFalse(MachiningDirection().isVerticalFromTop(direction))
        self.assertTrue(MachiningDirection().isVerticalFromBottom(direction))
