# -*- coding: utf-8 -*-

# Copyright 2017-2020, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest


SURFACE_ORIGIN_FRONT_LEFT = 0
SURFACE_ORIGIN_FRONT_RIGHT = 1
SURFACE_ORIGIN_BACK_LEFT = 2
SURFACE_ORIGIN_BACK_RIGHT = 3


def isOriginFront(surfaceOrigin):
    return surfaceOrigin == SURFACE_ORIGIN_FRONT_LEFT or surfaceOrigin == SURFACE_ORIGIN_FRONT_RIGHT


def isOriginBack(surfaceOrigin):
    return surfaceOrigin == SURFACE_ORIGIN_BACK_LEFT or surfaceOrigin == SURFACE_ORIGIN_BACK_RIGHT


def isOriginLeft(surfaceOrigin):
    return surfaceOrigin == SURFACE_ORIGIN_FRONT_LEFT or surfaceOrigin == SURFACE_ORIGIN_BACK_LEFT


def isOriginRight(surfaceOrigin):
    return surfaceOrigin == SURFACE_ORIGIN_FRONT_RIGHT or surfaceOrigin == SURFACE_ORIGIN_BACK_RIGHT


def isStandardOrigin(surfaceOrigin):
    return surfaceOrigin == SURFACE_ORIGIN_FRONT_LEFT or surfaceOrigin == SURFACE_ORIGIN_BACK_RIGHT


class Tests(unittest.TestCase):
    def testFrontLeft(self):
        self.assertTrue(isOriginFront(SURFACE_ORIGIN_FRONT_LEFT))
        self.assertTrue(isOriginLeft(SURFACE_ORIGIN_FRONT_LEFT))
        self.assertFalse(isOriginBack(SURFACE_ORIGIN_FRONT_LEFT))
        self.assertFalse(isOriginRight(SURFACE_ORIGIN_FRONT_LEFT))
        self.assertTrue(isStandardOrigin(SURFACE_ORIGIN_FRONT_LEFT))

    def testFrontRight(self):
        self.assertTrue(isOriginFront(SURFACE_ORIGIN_FRONT_RIGHT))
        self.assertFalse(isOriginLeft(SURFACE_ORIGIN_FRONT_RIGHT))
        self.assertFalse(isOriginBack(SURFACE_ORIGIN_FRONT_RIGHT))
        self.assertTrue(isOriginRight(SURFACE_ORIGIN_FRONT_RIGHT))
        self.assertFalse(isStandardOrigin(SURFACE_ORIGIN_FRONT_RIGHT))

    def testBackLeft(self):
        self.assertFalse(isOriginFront(SURFACE_ORIGIN_BACK_LEFT))
        self.assertTrue(isOriginLeft(SURFACE_ORIGIN_BACK_LEFT))
        self.assertTrue(isOriginBack(SURFACE_ORIGIN_BACK_LEFT))
        self.assertFalse(isOriginRight(SURFACE_ORIGIN_BACK_LEFT))
        self.assertFalse(isStandardOrigin(SURFACE_ORIGIN_BACK_LEFT))

    def testBackRight(self):
        self.assertFalse(isOriginFront(SURFACE_ORIGIN_BACK_RIGHT))
        self.assertFalse(isOriginLeft(SURFACE_ORIGIN_BACK_RIGHT))
        self.assertTrue(isOriginBack(SURFACE_ORIGIN_BACK_RIGHT))
        self.assertTrue(isOriginRight(SURFACE_ORIGIN_BACK_RIGHT))
        self.assertTrue(isStandardOrigin(SURFACE_ORIGIN_BACK_RIGHT))
