# -*- coding: utf-8 -*-

# Copyright 2011-2023, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import copy

from interiorcad.backend.localization import getLocalizedString, LICENSE_ERRORS_RESOURCEGROUP
from interiorcad.interface.surface.actualdepths import getVerticalPocketActualDepth
from interiorcad.interface.surface.drilling2d import Drilling2D
from interiorcad.interface.surface.exportmethodnames import ExportKeys


class Pocket2D(Drilling2D):
    def __init__(self, position, direction, diameter=0, depth=0, zPosition=0):
        super().__init__(position, direction, diameter, depth, zPosition)

    def assignTool(self, _surface, _machineConfiguration):
        # Real tool assignment is done in interiorcad.backend.postprocessors.surfacepostprocessor.pocketfilter.PocketFilter
        pass

    def getExportKey(self):
        return ExportKeys.POCKET

    def __str__(self):
        result = ' '.join((
            'Pocket 2D:',
            super().__str__() + ";"
        ))
        return result

    @classmethod
    def createFromDrilling(cls, drilling):
        return cls(drilling.position, drilling.direction, drilling.diameter, drilling.depth, drilling.zPosition)

    def getStarterError(self, workpieceName):
        message = getLocalizedString(LICENSE_ERRORS_RESOURCEGROUP, 3, "License Error: Circular Pocket not activated. (Workpiece: {workpiece}, diameter: {diameter})")
        return message.format(workpiece=workpieceName, diameter=self.diameter)


class VerticalPocket2D(Pocket2D):
    def assignTool(self, surface, machineConfiguration):
        self.actualDepth = getVerticalPocketActualDepth(machineConfiguration, surface.thickness, self.depth)
        self.tool = machineConfiguration.toolDatabase.getBestToolForCircularPocket(self.diameter, self.actualDepth)
        self.assignToolIDFromTool()


class HorizontalPocket2D(Pocket2D):
    def assignTool(self, surface, machineConfiguration):
        self.actualDepth = copy.copy(self.depth)
        self.tool = machineConfiguration.toolDatabase.getBestToolForHorizontalCircularPocket(self.diameter, self.actualDepth)
        self.assignToolIDFromTool()
