# -*- coding: utf-8 -*-

# Copyright 2011-2021, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import unittest

from interiorcad.interface.geometry.cornervertex import CornerVertex
from interiorcad.interface.geometry.point import Point
from interiorcad.interface.geometry.polyline import Polyline
from interiorcad.interface.surface.contourmachining2d import ContourMachining2D
from interiorcad.interface.surface.exportmethodnames import ExportKeys


class Profile2D(ContourMachining2D):
    def __init__(self, path=None):
        super().__init__(path)

    def getExportKey(self):
        return ExportKeys.CONTOUR

    def __str__(self):
        result = ' '.join((
            'Profile 2D:',
            super().__str__()
         ))
        return result

    def __repr__(self):
        return self.__str__()

    def assignTool(self, surface, machineConfiguration):
        # TODO InnoWeek 2021-12: we have no idea which profile is wanted, so we have no idea which tool to use -- NG
        self.tool = None
        self.assignToolIDFromTool()


class Profile2DTests(unittest.TestCase):
    def setUp(self):
        self.polyline = Polyline(
            CornerVertex(Point(100, 100), visible=True),
            CornerVertex(Point(100, 0), visible=True),
            CornerVertex(Point(0, 0), visible=True),
        )
        self.profile = Profile2D(self.polyline)

    def testAContourShouldBeEqualToItself(self):
        self.assertEqual(self.profile, self.profile)

    def testAContourShouldNotBeEqualToAnotherWithADifferentPath(self):
        self.assertNotEqual(self.profile, Profile2D(Polyline()))

    def testIsClosedOnAnOpenPathShouldBeFalse(self):
        self.profile.path = Polyline(
            CornerVertex(Point(100, 100), visible=True),
            CornerVertex(Point(100, 0), visible=True),
            CornerVertex(Point(0, 0), visible=False),
        )
        self.assertFalse(self.profile.isClosed())

    def testIsClosedOnANonePathShouldBeFalse(self):
        self.profile.path = None
        self.assertFalse(self.profile.isClosed())

    def testIsClosedOnAClosedPathShouldBeTrue(self):
        self.assertTrue(self.profile.isClosed())

    def testIsClosedOnAPathReturningToStartShouldBeTrue(self):
        self.profile.path = Polyline(
            CornerVertex(Point(100, 100), visible=True),
            CornerVertex(Point(100, 0), visible=True),
            CornerVertex(Point(0, 0), visible=True),
            CornerVertex(Point(100, 100), visible=False),
        )
        self.assertTrue(self.profile.isClosed())

    def testIsValid(self):
        self.assertTrue(self.profile.isValid())

    def testNoPathShouldNotBeIsValid(self):
        self.profile.path = None
        self.assertFalse(self.profile.isValid())

    def testEmptyPathShouldNotBeIsValid(self):
        self.profile.path = Polyline()
        self.assertFalse(self.profile.isValid())
