# -*- coding: utf-8 -*-

# Copyright 2011-2020, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import copy
import unittest

from interiorcad.interface.geometry.point import Point
from interiorcad.interface.geometry.simplelinesegment import SimpleLineSegment
from interiorcad.interface.surface.dadorabbet2d import DadoRabbet2D
from interiorcad.interface.surface.exportmethodnames import ExportKeys


class Rabbet2D(DadoRabbet2D):
    def __init__(self, position=Point(0, 0), width=0, depth=0, length=0, directionVector=Point(1, 0), segment=None):
        super().__init__(position, width, depth, length, directionVector)
        self.segment = segment
        self.surface = None  # DO NOT USE! Only meant for supporting workpieceShape in old code.

    def assignTool(self, surface, machineConfiguration):
        self.actualDepth = copy.copy(self.depth)
        self.tool = machineConfiguration.toolDatabase.getBestToolForRabbet(self.width, self.actualDepth)
        self.assignToolIDFromTool()
        self.surface = surface  # DO NOT USE! Only meant for supporting workpieceShape in old code.

    def getExportKey(self):
        return ExportKeys.RABBET

    def __str__(self):
        return "Rabbet2D: {}, Segment: {}".format(super().__str__(), str(self.segment))

    def __eq__(self, rhs):
        return super().__eq__(rhs) and self.segment == rhs.segment

    def getPathLineSegment(self):
        return SimpleLineSegment(self.segment.start.position, self.segment.end.position)

    # Compatibility variable for old code (until 2018 F7); do NOT use for new code! Use directly finalFinishedSizeShape from Surface (but not through self.surface)
    @property
    def workpieceShape(self):
        if self.surface:
            return self.surface.finalFinishedSizeShape


class Tests(unittest.TestCase):
    def setUp(self):
        self.rabbet = Rabbet2D(Point(0, 0))

    def testEqualityOfRabbets(self):
        self.assertTrue(Rabbet2D() == Rabbet2D())
        self.assertEqual(Rabbet2D(), Rabbet2D())

    def testEqTestsAlsoSegment(self):
        rabbet1 = Rabbet2D(segment="mySegment")
        rabbet2 = Rabbet2D(segment="mySegment")
        self.assertTrue(rabbet1 == rabbet2)
        self.assertEqual(rabbet1, rabbet2)

    def testEqShouldRejectUnequalSegments(self):
        rabbet1 = Rabbet2D(segment="1")
        rabbet2 = Rabbet2D(segment="2")
        self.assertFalse(rabbet1 == rabbet2)
