# -*- coding: utf-8 -*-

# Copyright 2011-2019, extragroup GmbH, Pottkamp 19, 48149 Münster, Germany
# All rights reserved
#
# All information contained herein is, and remains the property of
# extragroup GmbH and its suppliers, if any. The intellectual and
# technical concepts contained herein are proprietary to extragroup GmbH
# and its suppliers and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material is
# strictly forbidden unless prior written permission is obtained from
# extragroup GmbH

import interiorcad.interface.machineconfiguration.machineconfigurationkeys as MachineConfigurationKeys
import interiorcad.backend.zvalue.constants as ZValueConstants

from interiorcad.ncexport.base import NCExportBase


# This class is a template for new WOP-Exports
class WOPExport(NCExportBase):
    EXPORT_FORMAT = 'This is a new WOP'

    def __init__(self, **keywords):
        super().__init__(**keywords)

        self.createZValueConverters(**keywords)

    def createZValueConverters(self, **keywords):
        self.zValueVerticalDrillingConverter = self.createZValueConverter(MachineConfigurationKeys.VERTICAL_DRILLING_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_TOP, ZValueConstants.Z_DIRECTION_DOWN)
        self.zValueHorizontalDrillingConverter = self.createZValueConverter(MachineConfigurationKeys.HORIZONTAL_DRILLING_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_TOP, ZValueConstants.Z_DIRECTION_DOWN)
        self.zValueVerticalPocketConverter = self.createZValueConverter(MachineConfigurationKeys.VERTICAL_POCKET_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_TOP, ZValueConstants.Z_DIRECTION_DOWN)
        self.zValueFiveAxisDrillingConverter = self.createZValueConverter(MachineConfigurationKeys.FIVE_AXIS_DRILLING_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_TOP, ZValueConstants.Z_DIRECTION_DOWN)
        self.zValueMillingConverter = self.createZValueConverter(MachineConfigurationKeys.MILLING_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_BOTTOM, ZValueConstants.Z_DIRECTION_UP)
        self.zValueDadoSawConverter = self.createZValueConverter(MachineConfigurationKeys.DADO_SAW_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_TOP, ZValueConstants.Z_DIRECTION_DOWN)
        self.zValueMiterSawConverter = self.createZValueConverter(MachineConfigurationKeys.MITER_SAW_Z_REFERENCE_KEY, ZValueConstants.ORIGIN_ON_BOTTOM, ZValueConstants.Z_DIRECTION_UP)

    def getNCFileExtension(self, **keywords):
        return '.txt'

    # Header
    def createHead(self, **keywords):
        return ''

    # Machinings
    def createSizingContour(self, **keywords):
        pass

    # Drillings
    def createVerticalDrilling(self, **keywords):
        return ''

    def createVerticalDrillingPiercing(self, **keywords):
        return ''

    def createRotatedHorizontalDrilling(self, **keywords):
        return ''

    def createFiveAxisDrilling(self, **keywords):
        return ''

    # Pockets
    def createVerticalPocket(self, **keywords):
        return ''

    def createVerticalPocketPiercing(self, **keywords):
        return ''

    # Contours
    def createVerticalRabbet(self, **keywords):
        return ''

    def createVerticalContour(self, **keywords):
        return ''

    def createNCStop(self, **keywords):
        return ''

    def createVerticalDadoWithRouter(self, **keywords):
        return ''

    def createVerticalDadoWithSawAlongXAxis(self, **keywords):
        return ''

    def createVerticalDadoWithSawAlongYAxis(self, **keywords):
        return ''

    def createVerticalDadoWithSawCRotated(self, **keywords):
        return ''

    # Miter
    def orientMiters(self, **keywords):
        pass

    # Footer
    def createEndOfFile(self, **keywords):
        return ''
